@@ -16,6 +16,8 @@ from bleak.backends.bluezdbus.advertisement_monitor import OrPattern
 from bleak.backends.bluezdbus.scanner import BlueZScannerArgs
 from bleak.backends.device import BLEDevice
 from bleak.backends.scanner import AdvertisementData, AdvertisementDataCallback
+from bleak_retry_connector import restore_discoveries
+from bluetooth_adapters import DEFAULT_ADDRESS
 from dbus_fast import InvalidMessageError
 
 from homeassistant.core import CALLBACK_TYPE, HomeAssistant, callback as hass_callback
@@ -24,15 +26,15 @@ from homeassistant.helpers.event import async_track_time_interval
 from homeassistant.util.dt import monotonic_time_coarse
 from homeassistant.util.package import is_docker_env
 
+from .base_scanner import BaseHaScanner
 from .const import (
-    DEFAULT_ADDRESS,
     SCANNER_WATCHDOG_INTERVAL,
     SCANNER_WATCHDOG_TIMEOUT,
     SOURCE_LOCAL,
     START_TIMEOUT,
 )
-from .models import BaseHaScanner, BluetoothScanningMode, BluetoothServiceInfoBleak
-from .util import adapter_human_name, async_reset_adapter
+from .models import BluetoothScanningMode, BluetoothServiceInfoBleak
+from .util import async_reset_adapter
 
 OriginalBleakScanner = bleak.BleakScanner
 MONOTONIC_TIME = monotonic_time_coarse
@@ -125,18 +127,19 @@ class HaScanner(BaseHaScanner):
         mode: BluetoothScanningMode,
         adapter: str,
         address: str,
+        new_info_callback: Callable[[BluetoothServiceInfoBleak], None],
     ) -> None:
         """Init bluetooth discovery."""
         source = address if address != DEFAULT_ADDRESS else adapter or SOURCE_LOCAL
-        super().__init__(hass, source)
+        super().__init__(hass, source, adapter)
         self.mode = mode
         self.adapter = adapter
         self._start_stop_lock = asyncio.Lock()
         self._cancel_watchdog: CALLBACK_TYPE | None = None
         self._last_detection = 0.0
         self._start_time = 0.0
-        self._callbacks: list[Callable[[BluetoothServiceInfoBleak], None]] = []
-        self.name = adapter_human_name(adapter, address)
+        self._new_info_callback = new_info_callback
+        self.scanning = False
 
     @property
     def discovered_devices(self) -> list[BLEDevice]:
@@ -168,22 +171,6 @@ class HaScanner(BaseHaScanner):
             "start_time": self._start_time,
         }
 
-    @hass_callback
-    def async_register_callback(
-        self, callback: Callable[[BluetoothServiceInfoBleak], None]
-    ) -> CALLBACK_TYPE:
-        """Register a callback.
-
-        Currently this is used to feed the callbacks into the
-        central manager.
-        """
-
-        def _remove() -> None:
-            self._callbacks.remove(callback)
-
-        self._callbacks.append(callback)
-        return _remove
-
     @hass_callback
     def _async_detection_callback(
         self,
@@ -206,21 +193,21 @@ class HaScanner(BaseHaScanner):
             # as the adapter is in a failure
             # state if all the data is empty.
             self._last_detection = callback_time
-        service_info = BluetoothServiceInfoBleak(
-            name=advertisement_data.local_name or device.name or device.address,
-            address=device.address,
-            rssi=device.rssi,
-            manufacturer_data=advertisement_data.manufacturer_data,
-            service_data=advertisement_data.service_data,
-            service_uuids=advertisement_data.service_uuids,
-            source=self.source,
-            device=device,
-            advertisement=advertisement_data,
-            connectable=True,
-            time=callback_time,
+        self._new_info_callback(
+            BluetoothServiceInfoBleak(
+                name=advertisement_data.local_name or device.name or device.address,
+                address=device.address,
+                rssi=advertisement_data.rssi,
+                manufacturer_data=advertisement_data.manufacturer_data,
+                service_data=advertisement_data.service_data,
+                service_uuids=advertisement_data.service_uuids,
+                source=self.source,
+                device=device,
+                advertisement=advertisement_data,
+                connectable=True,
+                time=callback_time,
+            )
         )
-        for callback in self._callbacks:
-            callback(service_info)
 
     async def async_start(self) -> None:
         """Start bluetooth scanner."""
@@ -326,7 +313,9 @@ class HaScanner(BaseHaScanner):
             # Everything is fine, break out of the loop
             break
 
+        self.scanning = True
         self._async_setup_scanner_watchdog()
+        await restore_discoveries(self.scanner, self.adapter)
 
     @hass_callback
     def _async_setup_scanner_watchdog(self) -> None:
@@ -399,6 +388,7 @@ class HaScanner(BaseHaScanner):
 
     async def _async_stop_scanner(self) -> None:
         """Stop bluetooth discovery under the lock."""
+        self.scanning = False
         _LOGGER.debug("%s: Stopping bluetooth discovery", self.name)
         try:
             await self.scanner.stop()  # type: ignore[no-untyped-call]
