@@ -18,7 +18,6 @@ from homeassistant.components.sensor import (
     SensorStateClass,
 )
 from homeassistant.const import (
-    ATTR_ATTRIBUTION,
     CONF_API_KEY,
     CONF_LATITUDE,
     CONF_LONGITUDE,
@@ -31,8 +30,6 @@ from homeassistant.const import (
     LENGTH_KILOMETERS,
     LENGTH_MILES,
     PERCENTAGE,
-    PRECIPITATION_INCHES,
-    PRECIPITATION_MILLIMETERS_PER_HOUR,
     PRESSURE_MBAR,
     SPEED_KILOMETERS_PER_HOUR,
     SPEED_METERS_PER_SECOND,
@@ -40,17 +37,17 @@ from homeassistant.const import (
     TEMP_CELSIUS,
     TEMP_FAHRENHEIT,
     UV_INDEX,
+    UnitOfVolumetricFlux,
 )
 from homeassistant.core import HomeAssistant
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
 from homeassistant.util import Throttle
+from homeassistant.util.unit_system import METRIC_SYSTEM
 
 _LOGGER = logging.getLogger(__name__)
 
-ATTRIBUTION = "Powered by Dark Sky"
-
 CONF_FORECAST = "forecast"
 CONF_HOURLY_FORECAST = "hourly_forecast"
 CONF_LANGUAGE = "language"
@@ -148,11 +145,11 @@ SENSOR_TYPES: dict[str, DarkskySensorEntityDescription] = {
     "precip_intensity": DarkskySensorEntityDescription(
         key="precip_intensity",
         name="Precip Intensity",
-        si_unit=PRECIPITATION_MILLIMETERS_PER_HOUR,
-        us_unit=PRECIPITATION_INCHES,
-        ca_unit=PRECIPITATION_MILLIMETERS_PER_HOUR,
-        uk_unit=PRECIPITATION_MILLIMETERS_PER_HOUR,
-        uk2_unit=PRECIPITATION_MILLIMETERS_PER_HOUR,
+        si_unit=UnitOfVolumetricFlux.MILLIMETERS_PER_HOUR,
+        us_unit=UnitOfVolumetricFlux.INCHES_PER_HOUR,
+        ca_unit=UnitOfVolumetricFlux.MILLIMETERS_PER_HOUR,
+        uk_unit=UnitOfVolumetricFlux.MILLIMETERS_PER_HOUR,
+        uk2_unit=UnitOfVolumetricFlux.MILLIMETERS_PER_HOUR,
         icon="mdi:weather-rainy",
         forecast_mode=["currently", "minutely", "hourly", "daily"],
     ),
@@ -394,11 +391,11 @@ SENSOR_TYPES: dict[str, DarkskySensorEntityDescription] = {
     "precip_intensity_max": DarkskySensorEntityDescription(
         key="precip_intensity_max",
         name="Daily Max Precip Intensity",
-        si_unit=PRECIPITATION_MILLIMETERS_PER_HOUR,
-        us_unit=PRECIPITATION_INCHES,
-        ca_unit=PRECIPITATION_MILLIMETERS_PER_HOUR,
-        uk_unit=PRECIPITATION_MILLIMETERS_PER_HOUR,
-        uk2_unit=PRECIPITATION_MILLIMETERS_PER_HOUR,
+        si_unit=UnitOfVolumetricFlux.MILLIMETERS_PER_HOUR,
+        us_unit=UnitOfVolumetricFlux.INCHES_PER_HOUR,
+        ca_unit=UnitOfVolumetricFlux.MILLIMETERS_PER_HOUR,
+        uk_unit=UnitOfVolumetricFlux.MILLIMETERS_PER_HOUR,
+        uk2_unit=UnitOfVolumetricFlux.MILLIMETERS_PER_HOUR,
         icon="mdi:thermometer",
         forecast_mode=["daily"],
     ),
@@ -587,7 +584,7 @@ def setup_platform(
 
     if CONF_UNITS in config:
         units = config[CONF_UNITS]
-    elif hass.config.units.is_metric:
+    elif hass.config.units is METRIC_SYSTEM:
         units = "si"
     else:
         units = "us"
@@ -647,8 +644,8 @@ def setup_platform(
 class DarkSkySensor(SensorEntity):
     """Implementation of a Dark Sky sensor."""
 
+    _attr_attribution = "Powered by Dark Sky"
     entity_description: DarkskySensorEntityDescription
-    _attr_extra_state_attributes = {ATTR_ATTRIBUTION: ATTRIBUTION}
 
     def __init__(
         self,
