@@ -19,27 +19,16 @@ from typing_extensions import Concatenate, ParamSpec
 from homeassistant import config_entries
 from homeassistant.components import media_source, ssdp
 from homeassistant.components.media_player import (
+    ATTR_MEDIA_EXTRA,
     BrowseMedia,
     MediaPlayerEntity,
     MediaPlayerEntityFeature,
+    MediaPlayerState,
+    MediaType,
+    RepeatMode,
     async_process_play_media_url,
 )
-from homeassistant.components.media_player.const import (
-    ATTR_MEDIA_EXTRA,
-    REPEAT_MODE_ALL,
-    REPEAT_MODE_OFF,
-    REPEAT_MODE_ONE,
-)
-from homeassistant.const import (
-    CONF_DEVICE_ID,
-    CONF_TYPE,
-    CONF_URL,
-    STATE_IDLE,
-    STATE_OFF,
-    STATE_ON,
-    STATE_PAUSED,
-    STATE_PLAYING,
-)
+from homeassistant.const import CONF_DEVICE_ID, CONF_TYPE, CONF_URL
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers import device_registry, entity_registry
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
@@ -466,38 +455,38 @@ class DlnaDmrEntity(MediaPlayerEntity):
         return f"{self.udn}::{self.device_type}"
 
     @property
-    def state(self) -> str | None:
+    def state(self) -> MediaPlayerState | None:
         """State of the player."""
         if not self._device or not self.available:
-            return STATE_OFF
+            return MediaPlayerState.OFF
         if self._device.transport_state is None:
-            return STATE_ON
+            return MediaPlayerState.ON
         if self._device.transport_state in (
             TransportState.PLAYING,
             TransportState.TRANSITIONING,
         ):
-            return STATE_PLAYING
+            return MediaPlayerState.PLAYING
         if self._device.transport_state in (
             TransportState.PAUSED_PLAYBACK,
             TransportState.PAUSED_RECORDING,
         ):
-            return STATE_PAUSED
+            return MediaPlayerState.PAUSED
         if self._device.transport_state == TransportState.VENDOR_DEFINED:
             # Unable to map this state to anything reasonable, so it's "Unknown"
             return None
 
-        return STATE_IDLE
+        return MediaPlayerState.IDLE
 
     @property
-    def supported_features(self) -> int:
+    def supported_features(self) -> MediaPlayerEntityFeature:
         """Flag media player features that are supported at this moment.
 
         Supported features may change as the device enters different states.
         """
         if not self._device:
-            return 0
+            return MediaPlayerEntityFeature(0)
 
-        supported_features = 0
+        supported_features = MediaPlayerEntityFeature(0)
 
         if self._device.has_volume_level:
             supported_features |= MediaPlayerEntityFeature.VOLUME_SET
@@ -578,7 +567,7 @@ class DlnaDmrEntity(MediaPlayerEntity):
         await self._device.async_stop()
 
     @catch_request_errors
-    async def async_media_seek(self, position: int | float) -> None:
+    async def async_media_seek(self, position: float) -> None:
         """Send seek command."""
         assert self._device is not None
         time = timedelta(seconds=position)
@@ -586,7 +575,7 @@ class DlnaDmrEntity(MediaPlayerEntity):
 
     @catch_request_errors
     async def async_play_media(
-        self, media_type: str, media_id: str, **kwargs: Any
+        self, media_type: MediaType | str, media_id: str, **kwargs: Any
     ) -> None:
         """Play a piece of media."""
         _LOGGER.debug("Playing media: %s, %s, %s", media_type, media_id, kwargs)
@@ -683,7 +672,7 @@ class DlnaDmrEntity(MediaPlayerEntity):
         """Enable/disable shuffle mode."""
         assert self._device is not None
 
-        repeat = self.repeat or REPEAT_MODE_OFF
+        repeat = self.repeat or RepeatMode.OFF
         potential_play_modes = SHUFFLE_PLAY_MODES[(shuffle, repeat)]
 
         valid_play_modes = self._device.valid_play_modes
@@ -698,7 +687,7 @@ class DlnaDmrEntity(MediaPlayerEntity):
         )
 
     @property
-    def repeat(self) -> str | None:
+    def repeat(self) -> RepeatMode | None:
         """Return current repeat mode."""
         if not self._device:
             return None
@@ -710,15 +699,15 @@ class DlnaDmrEntity(MediaPlayerEntity):
             return None
 
         if play_mode == PlayMode.REPEAT_ONE:
-            return REPEAT_MODE_ONE
+            return RepeatMode.ONE
 
         if play_mode in (PlayMode.REPEAT_ALL, PlayMode.RANDOM):
-            return REPEAT_MODE_ALL
+            return RepeatMode.ALL
 
-        return REPEAT_MODE_OFF
+        return RepeatMode.OFF
 
     @catch_request_errors
-    async def async_set_repeat(self, repeat: str) -> None:
+    async def async_set_repeat(self, repeat: RepeatMode) -> None:
         """Set repeat mode."""
         assert self._device is not None
 
@@ -839,7 +828,7 @@ class DlnaDmrEntity(MediaPlayerEntity):
         return self._device.current_track_uri
 
     @property
-    def media_content_type(self) -> str | None:
+    def media_content_type(self) -> MediaType | None:
         """Content type of current playing media."""
         if not self._device or not self._device.media_class:
             return None
