@@ -2,13 +2,15 @@
 from __future__ import annotations
 
 from homeassistant.helpers.entity import DeviceInfo, EntityDescription
-from homeassistant.helpers.update_coordinator import CoordinatorEntity
+from homeassistant.helpers.update_coordinator import (
+    CoordinatorEntity,
+    DataUpdateCoordinator,
+)
 
 from .const import DOMAIN
-from .coordinator import FlumeDeviceDataUpdateCoordinator
 
 
-class FlumeEntity(CoordinatorEntity[FlumeDeviceDataUpdateCoordinator]):
+class FlumeEntity(CoordinatorEntity[DataUpdateCoordinator[None]]):
     """Base entity class."""
 
     _attr_attribution = "Data provided by Flume API"
@@ -16,20 +18,29 @@ class FlumeEntity(CoordinatorEntity[FlumeDeviceDataUpdateCoordinator]):
 
     def __init__(
         self,
-        coordinator: FlumeDeviceDataUpdateCoordinator,
+        coordinator: DataUpdateCoordinator,
         description: EntityDescription,
         device_id: str,
+        location_name: str,
+        is_bridge: bool = False,
     ) -> None:
         """Class initializer."""
         super().__init__(coordinator)
         self.entity_description = description
         self.device_id = device_id
+
+        if is_bridge:
+            name = "Flume Bridge"
+        else:
+            name = "Flume Sensor"
+
         self._attr_unique_id = f"{description.key}_{device_id}"
+
         self._attr_device_info = DeviceInfo(
             identifiers={(DOMAIN, device_id)},
             manufacturer="Flume, Inc.",
             model="Flume Smart Water Monitor",
-            name=f"Flume {device_id}",
+            name=f"{name} {location_name}",
             configuration_url="https://portal.flumewater.com",
         )
 
