@@ -17,7 +17,7 @@ BOARD_NAMES = {
 
 
 @callback
-def async_info(hass: HomeAssistant) -> HardwareInfo:
+def async_info(hass: HomeAssistant) -> list[HardwareInfo]:
     """Return board info."""
     if (os_info := get_os_info(hass)) is None:
         raise HomeAssistantError
@@ -27,13 +27,21 @@ def async_info(hass: HomeAssistant) -> HardwareInfo:
     if not board.startswith("odroid"):
         raise HomeAssistantError
 
-    return HardwareInfo(
-        board=BoardInfo(
-            hassio_board_id=board,
-            manufacturer=DOMAIN,
-            model=board,
-            revision=None,
-        ),
-        name=BOARD_NAMES.get(board, f"Unknown hardkernel Odroid model '{board}'"),
-        url=None,
-    )
+    config_entries = [
+        entry.entry_id for entry in hass.config_entries.async_entries(DOMAIN)
+    ]
+
+    return [
+        HardwareInfo(
+            board=BoardInfo(
+                hassio_board_id=board,
+                manufacturer=DOMAIN,
+                model=board,
+                revision=None,
+            ),
+            config_entries=config_entries,
+            dongle=None,
+            name=BOARD_NAMES.get(board, f"Unknown hardkernel Odroid model '{board}'"),
+            url=None,
+        )
+    ]
