@@ -413,14 +413,40 @@ def density_to_air_quality(density: float) -> int:
 
 
 def density_to_air_quality_pm10(density: float) -> int:
-    """Map PM10 density to HomeKit AirQuality level."""
-    if density <= 40:
+    """Map PM10 µg/m3 density to HomeKit AirQuality level."""
+    if density <= 54:  # US AQI 0-50 (HomeKit: Excellent)
         return 1
-    if density <= 80:
+    if density <= 154:  # US AQI 51-100 (HomeKit: Good)
         return 2
-    if density <= 120:
+    if density <= 254:  # US AQI 101-150 (HomeKit: Fair)
         return 3
-    if density <= 300:
+    if density <= 354:  # US AQI 151-200 (HomeKit: Inferior)
+        return 4
+    return 5  # US AQI 201+ (HomeKit: Poor)
+
+
+def density_to_air_quality_nitrogen_dioxide(density: float) -> int:
+    """Map nitrogen dioxide µg/m3 to HomeKit AirQuality level."""
+    if density <= 30:
+        return 1
+    if density <= 60:
+        return 2
+    if density <= 80:
+        return 3
+    if density <= 90:
+        return 4
+    return 5
+
+
+def density_to_air_quality_voc(density: float) -> int:
+    """Map VOCs µg/m3 to HomeKit AirQuality level."""
+    if density <= 24:
+        return 1
+    if density <= 48:
+        return 2
+    if density <= 64:
+        return 3
+    if density <= 96:
         return 4
     return 5
 
