@@ -2,6 +2,7 @@
 from __future__ import annotations
 
 import asyncio
+import contextlib
 import logging
 
 import aiohomekit
@@ -20,7 +21,7 @@ from homeassistant.helpers.typing import ConfigType
 
 from .config_flow import normalize_hkid
 from .connection import HKDevice
-from .const import KNOWN_DEVICES, TRIGGERS
+from .const import KNOWN_DEVICES
 from .utils import async_get_controller
 
 _LOGGER = logging.getLogger(__name__)
@@ -39,9 +40,15 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
 
     try:
         await conn.async_setup()
-    except (AccessoryNotFoundError, EncryptionError, AccessoryDisconnectedError) as ex:
+    except (
+        asyncio.TimeoutError,
+        AccessoryNotFoundError,
+        EncryptionError,
+        AccessoryDisconnectedError,
+    ) as ex:
         del hass.data[KNOWN_DEVICES][conn.unique_id]
-        await conn.pairing.close()
+        with contextlib.suppress(asyncio.TimeoutError):
+            await conn.pairing.close()
         raise ConfigEntryNotReady from ex
 
     return True
@@ -52,7 +59,6 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
     await async_get_controller(hass)
 
     hass.data[KNOWN_DEVICES] = {}
-    hass.data[TRIGGERS] = {}
 
     async def _async_stop_homekit_controller(event: Event) -> None:
         await asyncio.gather(
