@@ -84,7 +84,7 @@ async def async_setup_entry(
                 entity.old_unique_id, entity.unique_id, Platform.BUTTON
             )
 
-        async_add_entities(entities, True)
+        async_add_entities(entities)
         return True
 
     conn.add_char_factory(async_add_characteristic)
