@@ -3,7 +3,7 @@ from datetime import timedelta
 import logging
 
 import async_timeout
-from huisbaasje import Huisbaasje, HuisbaasjeException
+from energyflip import EnergyFlip, EnergyFlipException
 
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import CONF_PASSWORD, CONF_USERNAME, Platform
@@ -31,7 +31,7 @@ _LOGGER = logging.getLogger(__name__)
 async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Set up Huisbaasje from a config entry."""
     # Create the Huisbaasje client
-    huisbaasje = Huisbaasje(
+    energyflip = EnergyFlip(
         username=entry.data[CONF_USERNAME],
         password=entry.data[CONF_PASSWORD],
         source_types=SOURCE_TYPES,
@@ -40,13 +40,13 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
 
     # Attempt authentication. If this fails, an exception is thrown
     try:
-        await huisbaasje.authenticate()
-    except HuisbaasjeException as exception:
+        await energyflip.authenticate()
+    except EnergyFlipException as exception:
         _LOGGER.error("Authentication failed: %s", str(exception))
         return False
 
     async def async_update_data():
-        return await async_update_huisbaasje(huisbaasje)
+        return await async_update_huisbaasje(energyflip)
 
     # Create a coordinator for polling updates
     coordinator = DataUpdateCoordinator(
@@ -80,17 +80,17 @@ async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     return unload_ok
 
 
-async def async_update_huisbaasje(huisbaasje):
+async def async_update_huisbaasje(energyflip):
     """Update the data by performing a request to Huisbaasje."""
     try:
         # Note: asyncio.TimeoutError and aiohttp.ClientError are already
         # handled by the data update coordinator.
         async with async_timeout.timeout(FETCH_TIMEOUT):
-            if not huisbaasje.is_authenticated():
+            if not energyflip.is_authenticated():
                 _LOGGER.warning("Huisbaasje is unauthenticated. Reauthenticating")
-                await huisbaasje.authenticate()
+                await energyflip.authenticate()
 
-            current_measurements = await huisbaasje.current_measurements()
+            current_measurements = await energyflip.current_measurements()
 
             return {
                 source_type: {
@@ -112,7 +112,7 @@ async def async_update_huisbaasje(huisbaasje):
                 }
                 for source_type in SOURCE_TYPES
             }
-    except HuisbaasjeException as exception:
+    except EnergyFlipException as exception:
         raise UpdateFailed(f"Error communicating with API: {exception}") from exception
 
 
