@@ -124,7 +124,7 @@ class LutronDevice(Entity):
         self._controller = controller
         self._area_name = area_name
 
-    async def async_added_to_hass(self):
+    async def async_added_to_hass(self) -> None:
         """Register callbacks."""
         self._lutron_device.subscribe(self._update_callback, None)
 
@@ -133,7 +133,7 @@ class LutronDevice(Entity):
         self.schedule_update_ha_state()
 
     @property
-    def name(self):
+    def name(self) -> str:
         """Return the name of the device."""
         return f"{self._area_name} {self._lutron_device.name}"
 
