@@ -12,25 +12,23 @@ import hashlib
 from http import HTTPStatus
 import logging
 import secrets
-from typing import Any, cast, final
-from urllib.parse import urlparse
+from typing import Any, Final, TypedDict, final
+from urllib.parse import quote, urlparse
 
 from aiohttp import web
 from aiohttp.hdrs import CACHE_CONTROL, CONTENT_TYPE
 from aiohttp.typedefs import LooseHeaders
 import async_timeout
+from typing_extensions import Required
 import voluptuous as vol
 from yarl import URL
 
 from homeassistant.backports.enum import StrEnum
 from homeassistant.components import websocket_api
 from homeassistant.components.http import KEY_AUTHENTICATED, HomeAssistantView
-from homeassistant.components.websocket_api.const import (
-    ERR_NOT_SUPPORTED,
-    ERR_UNKNOWN_ERROR,
-)
+from homeassistant.components.websocket_api import ERR_NOT_SUPPORTED, ERR_UNKNOWN_ERROR
 from homeassistant.config_entries import ConfigEntry
-from homeassistant.const import (
+from homeassistant.const import (  # noqa: F401
     SERVICE_MEDIA_NEXT_TRACK,
     SERVICE_MEDIA_PAUSE,
     SERVICE_MEDIA_PLAY,
@@ -127,22 +125,23 @@ from .const import (  # noqa: F401
     SUPPORT_VOLUME_MUTE,
     SUPPORT_VOLUME_SET,
     SUPPORT_VOLUME_STEP,
+    MediaClass,
     MediaPlayerEntityFeature,
+    MediaPlayerState,
+    MediaType,
+    RepeatMode,
 )
 from .errors import BrowseError
 
-# mypy: allow-untyped-defs, no-check-untyped-defs
-
 _LOGGER = logging.getLogger(__name__)
 
 ENTITY_ID_FORMAT = DOMAIN + ".{}"
 
-CACHE_IMAGES = "images"
-CACHE_MAXSIZE = "maxsize"
-CACHE_LOCK = "lock"
-CACHE_URL = "url"
-CACHE_CONTENT = "content"
-ENTITY_IMAGE_CACHE = {CACHE_IMAGES: collections.OrderedDict(), CACHE_MAXSIZE: 16}
+CACHE_IMAGES: Final = "images"
+CACHE_MAXSIZE: Final = "maxsize"
+CACHE_LOCK: Final = "lock"
+CACHE_URL: Final = "url"
+CACHE_CONTENT: Final = "content"
 
 SCAN_INTERVAL = dt.timedelta(seconds=10)
 
@@ -215,9 +214,28 @@ ATTR_TO_PROPERTY = [
     ATTR_MEDIA_REPEAT,
 ]
 
+# mypy: disallow-any-generics
+
+
+class _CacheImage(TypedDict, total=False):
+    """Class to hold a cached image."""
+
+    lock: Required[asyncio.Lock]
+    content: tuple[bytes | None, str | None]
+
+
+class _ImageCache(TypedDict):
+    """Class to hold a cached image."""
+
+    images: collections.OrderedDict[str, _CacheImage]
+    maxsize: int
+
+
+_ENTITY_IMAGE_CACHE = _ImageCache(images=collections.OrderedDict(), maxsize=16)
+
 
 @bind_hass
-def is_on(hass, entity_id=None):
+def is_on(hass: HomeAssistant, entity_id: str | None = None) -> bool:
     """
     Return true if specified media player entity_id is on.
 
@@ -225,7 +243,8 @@ def is_on(hass, entity_id=None):
     """
     entity_ids = [entity_id] if entity_id else hass.states.entity_ids(DOMAIN)
     return any(
-        not hass.states.is_state(entity_id, STATE_OFF) for entity_id in entity_ids
+        not hass.states.is_state(entity_id, MediaPlayerState.OFF)
+        for entity_id in entity_ids
     )
 
 
@@ -248,7 +267,7 @@ def _rename_keys(**keys: Any) -> Callable[[dict[str, Any]], dict[str, Any]]:
 
 async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
     """Track states and offer events for media_players."""
-    component = hass.data[DOMAIN] = EntityComponent(
+    component = hass.data[DOMAIN] = EntityComponent[MediaPlayerEntity](
         logging.getLogger(__name__), DOMAIN, hass, SCAN_INTERVAL
     )
 
@@ -367,7 +386,7 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
     )
 
     # Remove in Home Assistant 2022.9
-    def _rewrite_enqueue(value):
+    def _rewrite_enqueue(value: dict[str, Any]) -> dict[str, Any]:
         """Rewrite the enqueue value."""
         if ATTR_MEDIA_ENQUEUE not in value:
             pass
@@ -410,7 +429,7 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
 
     component.async_register_entity_service(
         SERVICE_REPEAT_SET,
-        {vol.Required(ATTR_MEDIA_REPEAT): vol.In(REPEAT_MODES)},
+        {vol.Required(ATTR_MEDIA_REPEAT): vol.Coerce(RepeatMode)},
         "async_set_repeat",
         [MediaPlayerEntityFeature.REPEAT_SET],
     )
@@ -420,13 +439,13 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
 
 async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Set up a config entry."""
-    component: EntityComponent = hass.data[DOMAIN]
+    component: EntityComponent[MediaPlayerEntity] = hass.data[DOMAIN]
     return await component.async_setup_entry(entry)
 
 
 async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Unload a config entry."""
-    component: EntityComponent = hass.data[DOMAIN]
+    component: EntityComponent[MediaPlayerEntity] = hass.data[DOMAIN]
     return await component.async_unload_entry(entry)
 
 
@@ -453,7 +472,7 @@ class MediaPlayerEntity(Entity):
     _attr_media_artist: str | None = None
     _attr_media_channel: str | None = None
     _attr_media_content_id: str | None = None
-    _attr_media_content_type: str | None = None
+    _attr_media_content_type: MediaType | str | None = None
     _attr_media_duration: int | None = None
     _attr_media_episode: str | None = None
     _attr_media_image_hash: str | None
@@ -466,14 +485,14 @@ class MediaPlayerEntity(Entity):
     _attr_media_series_title: str | None = None
     _attr_media_title: str | None = None
     _attr_media_track: int | None = None
-    _attr_repeat: str | None = None
+    _attr_repeat: RepeatMode | str | None = None
     _attr_shuffle: bool | None = None
     _attr_sound_mode_list: list[str] | None = None
     _attr_sound_mode: str | None = None
     _attr_source_list: list[str] | None = None
     _attr_source: str | None = None
-    _attr_state: str | None = None
-    _attr_supported_features: int = 0
+    _attr_state: MediaPlayerState | None = None
+    _attr_supported_features: MediaPlayerEntityFeature = MediaPlayerEntityFeature(0)
     _attr_volume_level: float | None = None
 
     # Implement these for your media player
@@ -487,7 +506,7 @@ class MediaPlayerEntity(Entity):
         return None
 
     @property
-    def state(self) -> str | None:
+    def state(self) -> MediaPlayerState | None:
         """State of the player."""
         return self._attr_state
 
@@ -514,7 +533,7 @@ class MediaPlayerEntity(Entity):
         return self._attr_media_content_id
 
     @property
-    def media_content_type(self) -> str | None:
+    def media_content_type(self) -> MediaType | str | None:
         """Content type of current playing media."""
         return self._attr_media_content_type
 
@@ -663,7 +682,7 @@ class MediaPlayerEntity(Entity):
         return self._attr_shuffle
 
     @property
-    def repeat(self) -> str | None:
+    def repeat(self) -> RepeatMode | str | None:
         """Return current repeat mode."""
         return self._attr_repeat
 
@@ -673,225 +692,247 @@ class MediaPlayerEntity(Entity):
         return self._attr_group_members
 
     @property
-    def supported_features(self) -> int:
+    def supported_features(self) -> MediaPlayerEntityFeature:
         """Flag media player features that are supported."""
         return self._attr_supported_features
 
-    def turn_on(self):
+    def turn_on(self) -> None:
         """Turn the media player on."""
         raise NotImplementedError()
 
-    async def async_turn_on(self):
+    async def async_turn_on(self) -> None:
         """Turn the media player on."""
         await self.hass.async_add_executor_job(self.turn_on)
 
-    def turn_off(self):
+    def turn_off(self) -> None:
         """Turn the media player off."""
         raise NotImplementedError()
 
-    async def async_turn_off(self):
+    async def async_turn_off(self) -> None:
         """Turn the media player off."""
         await self.hass.async_add_executor_job(self.turn_off)
 
-    def mute_volume(self, mute):
+    def mute_volume(self, mute: bool) -> None:
         """Mute the volume."""
         raise NotImplementedError()
 
-    async def async_mute_volume(self, mute):
+    async def async_mute_volume(self, mute: bool) -> None:
         """Mute the volume."""
         await self.hass.async_add_executor_job(self.mute_volume, mute)
 
-    def set_volume_level(self, volume):
+    def set_volume_level(self, volume: float) -> None:
         """Set volume level, range 0..1."""
         raise NotImplementedError()
 
-    async def async_set_volume_level(self, volume):
+    async def async_set_volume_level(self, volume: float) -> None:
         """Set volume level, range 0..1."""
         await self.hass.async_add_executor_job(self.set_volume_level, volume)
 
-    def media_play(self):
+    def media_play(self) -> None:
         """Send play command."""
         raise NotImplementedError()
 
-    async def async_media_play(self):
+    async def async_media_play(self) -> None:
         """Send play command."""
         await self.hass.async_add_executor_job(self.media_play)
 
-    def media_pause(self):
+    def media_pause(self) -> None:
         """Send pause command."""
         raise NotImplementedError()
 
-    async def async_media_pause(self):
+    async def async_media_pause(self) -> None:
         """Send pause command."""
         await self.hass.async_add_executor_job(self.media_pause)
 
-    def media_stop(self):
+    def media_stop(self) -> None:
         """Send stop command."""
         raise NotImplementedError()
 
-    async def async_media_stop(self):
+    async def async_media_stop(self) -> None:
         """Send stop command."""
         await self.hass.async_add_executor_job(self.media_stop)
 
-    def media_previous_track(self):
+    def media_previous_track(self) -> None:
         """Send previous track command."""
         raise NotImplementedError()
 
-    async def async_media_previous_track(self):
+    async def async_media_previous_track(self) -> None:
         """Send previous track command."""
         await self.hass.async_add_executor_job(self.media_previous_track)
 
-    def media_next_track(self):
+    def media_next_track(self) -> None:
         """Send next track command."""
         raise NotImplementedError()
 
-    async def async_media_next_track(self):
+    async def async_media_next_track(self) -> None:
         """Send next track command."""
         await self.hass.async_add_executor_job(self.media_next_track)
 
-    def media_seek(self, position):
+    def media_seek(self, position: float) -> None:
         """Send seek command."""
         raise NotImplementedError()
 
-    async def async_media_seek(self, position):
+    async def async_media_seek(self, position: float) -> None:
         """Send seek command."""
         await self.hass.async_add_executor_job(self.media_seek, position)
 
-    def play_media(self, media_type, media_id, **kwargs):
+    def play_media(
+        self, media_type: MediaType | str, media_id: str, **kwargs: Any
+    ) -> None:
         """Play a piece of media."""
         raise NotImplementedError()
 
-    async def async_play_media(self, media_type, media_id, **kwargs):
+    async def async_play_media(
+        self, media_type: MediaType | str, media_id: str, **kwargs: Any
+    ) -> None:
         """Play a piece of media."""
         await self.hass.async_add_executor_job(
             ft.partial(self.play_media, media_type, media_id, **kwargs)
         )
 
-    def select_source(self, source):
+    def select_source(self, source: str) -> None:
         """Select input source."""
         raise NotImplementedError()
 
-    async def async_select_source(self, source):
+    async def async_select_source(self, source: str) -> None:
         """Select input source."""
         await self.hass.async_add_executor_job(self.select_source, source)
 
-    def select_sound_mode(self, sound_mode):
+    def select_sound_mode(self, sound_mode: str) -> None:
         """Select sound mode."""
         raise NotImplementedError()
 
-    async def async_select_sound_mode(self, sound_mode):
+    async def async_select_sound_mode(self, sound_mode: str) -> None:
         """Select sound mode."""
         await self.hass.async_add_executor_job(self.select_sound_mode, sound_mode)
 
-    def clear_playlist(self):
+    def clear_playlist(self) -> None:
         """Clear players playlist."""
         raise NotImplementedError()
 
-    async def async_clear_playlist(self):
+    async def async_clear_playlist(self) -> None:
         """Clear players playlist."""
         await self.hass.async_add_executor_job(self.clear_playlist)
 
-    def set_shuffle(self, shuffle):
+    def set_shuffle(self, shuffle: bool) -> None:
         """Enable/disable shuffle mode."""
         raise NotImplementedError()
 
-    async def async_set_shuffle(self, shuffle):
+    async def async_set_shuffle(self, shuffle: bool) -> None:
         """Enable/disable shuffle mode."""
         await self.hass.async_add_executor_job(self.set_shuffle, shuffle)
 
-    def set_repeat(self, repeat):
+    def set_repeat(self, repeat: RepeatMode) -> None:
         """Set repeat mode."""
         raise NotImplementedError()
 
-    async def async_set_repeat(self, repeat):
+    async def async_set_repeat(self, repeat: RepeatMode) -> None:
         """Set repeat mode."""
         await self.hass.async_add_executor_job(self.set_repeat, repeat)
 
     # No need to overwrite these.
+    @final
     @property
-    def support_play(self):
+    def support_play(self) -> bool:
         """Boolean if play is supported."""
         return bool(self.supported_features & MediaPlayerEntityFeature.PLAY)
 
+    @final
     @property
-    def support_pause(self):
+    def support_pause(self) -> bool:
         """Boolean if pause is supported."""
         return bool(self.supported_features & MediaPlayerEntityFeature.PAUSE)
 
+    @final
     @property
-    def support_stop(self):
+    def support_stop(self) -> bool:
         """Boolean if stop is supported."""
         return bool(self.supported_features & MediaPlayerEntityFeature.STOP)
 
+    @final
     @property
-    def support_seek(self):
+    def support_seek(self) -> bool:
         """Boolean if seek is supported."""
         return bool(self.supported_features & MediaPlayerEntityFeature.SEEK)
 
+    @final
     @property
-    def support_volume_set(self):
+    def support_volume_set(self) -> bool:
         """Boolean if setting volume is supported."""
         return bool(self.supported_features & MediaPlayerEntityFeature.VOLUME_SET)
 
+    @final
     @property
-    def support_volume_mute(self):
+    def support_volume_mute(self) -> bool:
         """Boolean if muting volume is supported."""
         return bool(self.supported_features & MediaPlayerEntityFeature.VOLUME_MUTE)
 
+    @final
     @property
-    def support_previous_track(self):
+    def support_previous_track(self) -> bool:
         """Boolean if previous track command supported."""
         return bool(self.supported_features & MediaPlayerEntityFeature.PREVIOUS_TRACK)
 
+    @final
     @property
-    def support_next_track(self):
+    def support_next_track(self) -> bool:
         """Boolean if next track command supported."""
         return bool(self.supported_features & MediaPlayerEntityFeature.NEXT_TRACK)
 
+    @final
     @property
-    def support_play_media(self):
+    def support_play_media(self) -> bool:
         """Boolean if play media command supported."""
         return bool(self.supported_features & MediaPlayerEntityFeature.PLAY_MEDIA)
 
+    @final
     @property
-    def support_select_source(self):
+    def support_select_source(self) -> bool:
         """Boolean if select source command supported."""
         return bool(self.supported_features & MediaPlayerEntityFeature.SELECT_SOURCE)
 
+    @final
     @property
-    def support_select_sound_mode(self):
+    def support_select_sound_mode(self) -> bool:
         """Boolean if select sound mode command supported."""
         return bool(
             self.supported_features & MediaPlayerEntityFeature.SELECT_SOUND_MODE
         )
 
+    @final
     @property
-    def support_clear_playlist(self):
+    def support_clear_playlist(self) -> bool:
         """Boolean if clear playlist command supported."""
         return bool(self.supported_features & MediaPlayerEntityFeature.CLEAR_PLAYLIST)
 
+    @final
     @property
-    def support_shuffle_set(self):
+    def support_shuffle_set(self) -> bool:
         """Boolean if shuffle is supported."""
         return bool(self.supported_features & MediaPlayerEntityFeature.SHUFFLE_SET)
 
+    @final
     @property
-    def support_grouping(self):
+    def support_grouping(self) -> bool:
         """Boolean if player grouping is supported."""
         return bool(self.supported_features & MediaPlayerEntityFeature.GROUPING)
 
-    async def async_toggle(self):
+    async def async_toggle(self) -> None:
         """Toggle the power on the media player."""
         if hasattr(self, "toggle"):
             await self.hass.async_add_executor_job(self.toggle)
             return
 
-        if self.state in (STATE_OFF, STATE_IDLE, STATE_STANDBY):
+        if self.state in {
+            MediaPlayerState.OFF,
+            MediaPlayerState.IDLE,
+            MediaPlayerState.STANDBY,
+        }:
             await self.async_turn_on()
         else:
             await self.async_turn_off()
 
-    async def async_volume_up(self):
+    async def async_volume_up(self) -> None:
         """Turn volume up for media player.
 
         This method is a coroutine.
@@ -901,12 +942,13 @@ class MediaPlayerEntity(Entity):
             return
 
         if (
-            self.volume_level < 1
+            self.volume_level is not None
+            and self.volume_level < 1
             and self.supported_features & MediaPlayerEntityFeature.VOLUME_SET
         ):
             await self.async_set_volume_level(min(1, self.volume_level + 0.1))
 
-    async def async_volume_down(self):
+    async def async_volume_down(self) -> None:
         """Turn volume down for media player.
 
         This method is a coroutine.
@@ -916,26 +958,27 @@ class MediaPlayerEntity(Entity):
             return
 
         if (
-            self.volume_level > 0
+            self.volume_level is not None
+            and self.volume_level > 0
             and self.supported_features & MediaPlayerEntityFeature.VOLUME_SET
         ):
             await self.async_set_volume_level(max(0, self.volume_level - 0.1))
 
-    async def async_media_play_pause(self):
+    async def async_media_play_pause(self) -> None:
         """Play or pause the media player."""
         if hasattr(self, "media_play_pause"):
             await self.hass.async_add_executor_job(self.media_play_pause)
             return
 
-        if self.state == STATE_PLAYING:
+        if self.state == MediaPlayerState.PLAYING:
             await self.async_media_pause()
         else:
             await self.async_media_play()
 
     @property
-    def entity_picture(self):
+    def entity_picture(self) -> str | None:
         """Return image of the media playing."""
-        if self.state == STATE_OFF:
+        if self.state == MediaPlayerState.OFF:
             return None
 
         if self.media_image_remotely_accessible:
@@ -944,7 +987,7 @@ class MediaPlayerEntity(Entity):
         return self.media_image_local
 
     @property
-    def media_image_local(self):
+    def media_image_local(self) -> str | None:
         """Return local url to media image."""
         if (image_hash := self.media_image_hash) is None:
             return None
@@ -955,17 +998,16 @@ class MediaPlayerEntity(Entity):
         )
 
     @property
-    def capability_attributes(self):
+    def capability_attributes(self) -> dict[str, Any]:
         """Return capability attributes."""
-        supported_features = self.supported_features or 0
-        data = {}
+        data: dict[str, Any] = {}
 
-        if supported_features & MediaPlayerEntityFeature.SELECT_SOURCE and (
+        if self.supported_features & MediaPlayerEntityFeature.SELECT_SOURCE and (
             source_list := self.source_list
         ):
             data[ATTR_INPUT_SOURCE_LIST] = source_list
 
-        if supported_features & MediaPlayerEntityFeature.SELECT_SOUND_MODE and (
+        if self.supported_features & MediaPlayerEntityFeature.SELECT_SOUND_MODE and (
             sound_mode_list := self.sound_mode_list
         ):
             data[ATTR_SOUND_MODE_LIST] = sound_mode_list
@@ -974,14 +1016,14 @@ class MediaPlayerEntity(Entity):
 
     @final
     @property
-    def state_attributes(self):
+    def state_attributes(self) -> dict[str, Any]:
         """Return the state attributes."""
-        state_attr = {}
+        state_attr: dict[str, Any] = {}
 
         if self.support_grouping:
             state_attr[ATTR_GROUP_MEMBERS] = self.group_members
 
-        if self.state == STATE_OFF:
+        if self.state == MediaPlayerState.OFF:
             return state_attr
 
         for attr in ATTR_TO_PROPERTY:
@@ -1005,19 +1047,19 @@ class MediaPlayerEntity(Entity):
         """
         raise NotImplementedError()
 
-    def join_players(self, group_members):
+    def join_players(self, group_members: list[str]) -> None:
         """Join `group_members` as a player group with the current player."""
         raise NotImplementedError()
 
-    async def async_join_players(self, group_members):
+    async def async_join_players(self, group_members: list[str]) -> None:
         """Join `group_members` as a player group with the current player."""
         await self.hass.async_add_executor_job(self.join_players, group_members)
 
-    def unjoin_player(self):
+    def unjoin_player(self) -> None:
         """Remove this player from any group."""
         raise NotImplementedError()
 
-    async def async_unjoin_player(self):
+    async def async_unjoin_player(self) -> None:
         """Remove this player from any group."""
         await self.hass.async_add_executor_job(self.unjoin_player)
 
@@ -1028,8 +1070,8 @@ class MediaPlayerEntity(Entity):
 
         Images are cached in memory (the images are typically 10-100kB in size).
         """
-        cache_images = cast(collections.OrderedDict, ENTITY_IMAGE_CACHE[CACHE_IMAGES])
-        cache_maxsize = cast(int, ENTITY_IMAGE_CACHE[CACHE_MAXSIZE])
+        cache_images = _ENTITY_IMAGE_CACHE[CACHE_IMAGES]
+        cache_maxsize = _ENTITY_IMAGE_CACHE[CACHE_MAXSIZE]
 
         if urlparse(url).hostname is None:
             url = f"{get_url(self.hass)}{url}"
@@ -1039,7 +1081,7 @@ class MediaPlayerEntity(Entity):
 
         async with cache_images[url][CACHE_LOCK]:
             if CACHE_CONTENT in cache_images[url]:
-                return cache_images[url][CACHE_CONTENT]  # type:ignore[no-any-return]
+                return cache_images[url][CACHE_CONTENT]
 
         (content, content_type) = await self._async_fetch_image(url)
 
@@ -1063,7 +1105,9 @@ class MediaPlayerEntity(Entity):
         """Generate an url for a media browser image."""
         url_path = (
             f"/api/media_player_proxy/{self.entity_id}/browse_media"
-            f"/{media_content_type}/{media_content_id}"
+            # quote the media_content_id as it may contain url unsafe characters
+            # aiohttp will unquote the path automatically
+            f"/{media_content_type}/{quote(media_content_id)}"
         )
 
         url_query = {"token": self.access_token}
@@ -1080,10 +1124,13 @@ class MediaPlayerImageView(HomeAssistantView):
     url = "/api/media_player_proxy/{entity_id}"
     name = "api:media_player:image"
     extra_urls = [
-        url + "/browse_media/{media_content_type}/{media_content_id}",
+        # Need to modify the default regex for media_content_id as it may
+        # include arbitrary characters including '/','{', or '}'
+        url
+        + "/browse_media/{media_content_type}/{media_content_id:.+}",
     ]
 
-    def __init__(self, component: EntityComponent) -> None:
+    def __init__(self, component: EntityComponent[MediaPlayerEntity]) -> None:
         """Initialize a media player view."""
         self.component = component
 
@@ -1144,14 +1191,18 @@ class MediaPlayerImageView(HomeAssistantView):
     }
 )
 @websocket_api.async_response
-async def websocket_browse_media(hass, connection, msg):
+async def websocket_browse_media(
+    hass: HomeAssistant,
+    connection: websocket_api.connection.ActiveConnection,
+    msg: dict[str, Any],
+) -> None:
     """
     Browse media available to the media_player entity.
 
     To use, media_player integrations can implement MediaPlayerEntity.async_browse_media()
     """
-    component = hass.data[DOMAIN]
-    player: MediaPlayerEntity | None = component.get_entity(msg["entity_id"])
+    component: EntityComponent[MediaPlayerEntity] = hass.data[DOMAIN]
+    player = component.get_entity(msg["entity_id"])
 
     if player is None:
         connection.send_error(msg["id"], "entity_not_found", "Entity not found")
@@ -1171,6 +1222,7 @@ async def websocket_browse_media(hass, connection, msg):
     try:
         payload = await player.async_browse_media(media_content_type, media_content_id)
     except NotImplementedError:
+        assert player.platform
         _LOGGER.error(
             "%s allows media browsing but its integration (%s) does not",
             player.entity_id,
@@ -1192,11 +1244,12 @@ async def websocket_browse_media(hass, connection, msg):
 
     # For backwards compat
     if isinstance(payload, BrowseMedia):
-        payload = payload.as_dict()
+        result = payload.as_dict()
     else:
+        result = payload  # type: ignore[unreachable]
         _LOGGER.warning("Browse Media should use new BrowseMedia class")
 
-    connection.send_result(msg["id"], payload)
+    connection.send_result(msg["id"], result)
 
 
 async def async_fetch_image(
