@@ -240,10 +240,11 @@ def warn_for_legacy_schema(domain: str) -> Callable[[ConfigType], ConfigType]:
         """Return a validator."""
         nonlocal warned
 
+        # Logged error and repair can be removed from HA 2023.6
         if domain in warned:
             return config
 
-        _LOGGER.warning(
+        _LOGGER.error(
             "Manually configured MQTT %s(s) found under platform key '%s', "
             "please move to the mqtt integration key, see "
             "https://www.home-assistant.io/integrations/%s.mqtt/#new_format",
@@ -259,7 +260,7 @@ def warn_for_legacy_schema(domain: str) -> Callable[[ConfigType], ConfigType]:
             f"deprecated_yaml_{domain}",
             breaks_in_ha_version="2022.12.0",  # Warning first added in 2022.6.0
             is_fixable=False,
-            severity=IssueSeverity.WARNING,
+            severity=IssueSeverity.ERROR,
             translation_key="deprecated_yaml",
             translation_placeholders={
                 "more_info_url": f"https://www.home-assistant.io/integrations/{domain}.mqtt/#new_format",
@@ -366,33 +367,6 @@ async def async_setup_entry_helper(
     await _async_setup_entities()
 
 
-async def async_setup_platform_helper(
-    hass: HomeAssistant,
-    platform_domain: str,
-    config: ConfigType,
-    async_add_entities: AddEntitiesCallback,
-    async_setup_entities: SetupEntity,
-) -> None:
-    """Help to set up the platform for manual configured MQTT entities."""
-    mqtt_data = get_mqtt_data(hass)
-    if mqtt_data.reload_entry:
-        _LOGGER.debug(
-            "MQTT integration is %s, skipping setup of manually configured MQTT items while unloading the config entry",
-            platform_domain,
-        )
-        return
-    if not (entry_status := mqtt_config_entry_enabled(hass)):
-        _LOGGER.warning(
-            "MQTT integration is %s, skipping setup of manually configured MQTT %s",
-            "not setup" if entry_status is None else "disabled",
-            platform_domain,
-        )
-        return
-    # Ensure we set config_entry when entries are set up to enable clean up
-    config_entry: ConfigEntry = hass.config_entries.async_entries(DOMAIN)[0]
-    await async_setup_entities(hass, async_add_entities, config, config_entry)
-
-
 def init_entity_id_from_config(
     hass: HomeAssistant, entity: Entity, config: ConfigType, entity_id_format: str
 ) -> None:
@@ -646,7 +620,8 @@ async def cleanup_device_registry(
 
 def get_discovery_hash(discovery_data: DiscoveryInfoType) -> tuple[str, str]:
     """Get the discovery hash from the discovery data."""
-    return discovery_data[ATTR_DISCOVERY_HASH]
+    discovery_hash: tuple[str, str] = discovery_data[ATTR_DISCOVERY_HASH]
+    return discovery_hash
 
 
 def send_discovery_done(hass: HomeAssistant, discovery_data: DiscoveryInfoType) -> None:
@@ -1107,7 +1082,7 @@ class MqttEntity(
         payload: PublishPayloadType,
         qos: int = 0,
         retain: bool = False,
-        encoding: str = DEFAULT_ENCODING,
+        encoding: str | None = DEFAULT_ENCODING,
     ) -> None:
         """Publish message to an MQTT topic."""
         log_message(self.hass, self.entity_id, topic, payload, qos, retain)
@@ -1139,7 +1114,7 @@ class MqttEntity(
     @property
     def entity_registry_enabled_default(self) -> bool:
         """Return if the entity should be enabled when first added to the entity registry."""
-        return self._config[CONF_ENABLED_BY_DEFAULT]
+        return bool(self._config[CONF_ENABLED_BY_DEFAULT])
 
     @property
     def entity_category(self) -> EntityCategory | None:
