@@ -1,6 +1,7 @@
 """Configure number in a device through MQTT topic."""
 from __future__ import annotations
 
+from collections.abc import Callable
 import functools
 import logging
 
@@ -12,7 +13,6 @@ from homeassistant.components.number import (
     DEFAULT_MIN_VALUE,
     DEFAULT_STEP,
     DEVICE_CLASSES_SCHEMA,
-    NumberDeviceClass,
     NumberMode,
     RestoreNumber,
 )
@@ -45,10 +45,15 @@ from .mixins import (
     MQTT_ENTITY_COMMON_SCHEMA,
     MqttEntity,
     async_setup_entry_helper,
-    async_setup_platform_helper,
     warn_for_legacy_schema,
 )
-from .models import MqttCommandTemplate, MqttValueTemplate
+from .models import (
+    MqttCommandTemplate,
+    MqttValueTemplate,
+    PublishPayloadType,
+    ReceiveMessage,
+    ReceivePayloadType,
+)
 from .util import get_mqtt_data
 
 _LOGGER = logging.getLogger(__name__)
@@ -71,9 +76,9 @@ MQTT_NUMBER_ATTRIBUTES_BLOCKED = frozenset(
 )
 
 
-def validate_config(config):
+def validate_config(config: ConfigType) -> ConfigType:
     """Validate that the configuration is valid, throws if it isn't."""
-    if config.get(CONF_MIN) >= config.get(CONF_MAX):
+    if config[CONF_MIN] >= config[CONF_MAX]:
         raise vol.Invalid(f"'{CONF_MAX}' must be > '{CONF_MIN}'")
 
     return config
@@ -102,10 +107,9 @@ PLATFORM_SCHEMA_MODERN = vol.All(
     validate_config,
 )
 
-# Configuring MQTT Number under the number platform key is deprecated in HA Core 2022.6
+# Configuring MQTT Number under the number platform key was deprecated in HA Core 2022.6
+# Setup for the legacy YAML format was removed in HA Core 2022.12
 PLATFORM_SCHEMA = vol.All(
-    cv.PLATFORM_SCHEMA.extend(_PLATFORM_SCHEMA_BASE.schema),
-    validate_config,
     warn_for_legacy_schema(number.DOMAIN),
 )
 
@@ -115,23 +119,6 @@ DISCOVERY_SCHEMA = vol.All(
 )
 
 
-async def async_setup_platform(
-    hass: HomeAssistant,
-    config: ConfigType,
-    async_add_entities: AddEntitiesCallback,
-    discovery_info: DiscoveryInfoType | None = None,
-) -> None:
-    """Set up MQTT number configured under the number platform key (deprecated)."""
-    # Deprecated in HA Core 2022.6
-    await async_setup_platform_helper(
-        hass,
-        number.DOMAIN,
-        discovery_info or config,
-        async_add_entities,
-        _async_setup_entity,
-    )
-
-
 async def async_setup_entry(
     hass: HomeAssistant,
     config_entry: ConfigEntry,
@@ -148,8 +135,8 @@ async def _async_setup_entity(
     hass: HomeAssistant,
     async_add_entities: AddEntitiesCallback,
     config: ConfigType,
-    config_entry: ConfigEntry | None = None,
-    discovery_data: dict | None = None,
+    config_entry: ConfigEntry,
+    discovery_data: DiscoveryInfoType | None = None,
 ) -> None:
     """Set up the MQTT number."""
     async_add_entities([MqttNumber(hass, config, config_entry, discovery_data)])
@@ -161,44 +148,55 @@ class MqttNumber(MqttEntity, RestoreNumber):
     _entity_id_format = number.ENTITY_ID_FORMAT
     _attributes_extra_blocked = MQTT_NUMBER_ATTRIBUTES_BLOCKED
 
-    def __init__(self, hass, config, config_entry, discovery_data):
+    _optimistic: bool
+    _command_template: Callable[[PublishPayloadType], PublishPayloadType]
+    _value_template: Callable[[ReceivePayloadType], ReceivePayloadType]
+
+    def __init__(
+        self,
+        hass: HomeAssistant,
+        config: ConfigType,
+        config_entry: ConfigEntry,
+        discovery_data: DiscoveryInfoType | None,
+    ) -> None:
         """Initialize the MQTT Number."""
-        self._config = config
-        self._optimistic = False
-        self._sub_state = None
-
-        self._current_number = None
-
         RestoreNumber.__init__(self)
         MqttEntity.__init__(self, hass, config, config_entry, discovery_data)
 
     @staticmethod
-    def config_schema():
+    def config_schema() -> vol.Schema:
         """Return the config schema."""
         return DISCOVERY_SCHEMA
 
-    def _setup_from_config(self, config):
+    def _setup_from_config(self, config: ConfigType) -> None:
         """(Re)Setup the entity."""
+        self._config = config
         self._optimistic = config[CONF_OPTIMISTIC]
 
-        self._templates = {
-            CONF_COMMAND_TEMPLATE: MqttCommandTemplate(
-                config.get(CONF_COMMAND_TEMPLATE), entity=self
-            ).async_render,
-            CONF_VALUE_TEMPLATE: MqttValueTemplate(
-                config.get(CONF_VALUE_TEMPLATE),
-                entity=self,
-            ).async_render_with_possible_json_value,
-        }
+        self._command_template = MqttCommandTemplate(
+            config.get(CONF_COMMAND_TEMPLATE), entity=self
+        ).async_render
+        self._value_template = MqttValueTemplate(
+            config.get(CONF_VALUE_TEMPLATE),
+            entity=self,
+        ).async_render_with_possible_json_value
 
-    def _prepare_subscribe_topics(self):
+        self._attr_device_class = config.get(CONF_DEVICE_CLASS)
+        self._attr_mode = config[CONF_MODE]
+        self._attr_native_max_value = config[CONF_MAX]
+        self._attr_native_min_value = config[CONF_MIN]
+        self._attr_native_step = config[CONF_STEP]
+        self._attr_native_unit_of_measurement = config.get(CONF_UNIT_OF_MEASUREMENT)
+
+    def _prepare_subscribe_topics(self) -> None:
         """(Re)Subscribe to topics."""
 
         @callback
         @log_messages(self.hass, self.entity_id)
-        def message_received(msg):
+        def message_received(msg: ReceiveMessage) -> None:
             """Handle new MQTT messages."""
-            payload = self._templates[CONF_VALUE_TEMPLATE](msg.payload)
+            num_value: int | float | None
+            payload = str(self._value_template(msg.payload))
             try:
                 if payload == self._config[CONF_PAYLOAD_RESET]:
                     num_value = None
@@ -222,7 +220,7 @@ class MqttNumber(MqttEntity, RestoreNumber):
                 )
                 return
 
-            self._current_number = num_value
+            self._attr_native_value = num_value
             get_mqtt_data(self.hass).state_write_requests.write_state_request(self)
 
         if self._config.get(CONF_STATE_TOPIC) is None:
@@ -242,44 +240,14 @@ class MqttNumber(MqttEntity, RestoreNumber):
                 },
             )
 
-    async def _subscribe_topics(self):
+    async def _subscribe_topics(self) -> None:
         """(Re)Subscribe to topics."""
         await subscription.async_subscribe_topics(self.hass, self._sub_state)
 
         if self._optimistic and (
             last_number_data := await self.async_get_last_number_data()
         ):
-            self._current_number = last_number_data.native_value
-
-    @property
-    def native_min_value(self) -> float:
-        """Return the minimum value."""
-        return self._config[CONF_MIN]
-
-    @property
-    def native_max_value(self) -> float:
-        """Return the maximum value."""
-        return self._config[CONF_MAX]
-
-    @property
-    def native_step(self) -> float:
-        """Return the increment/decrement step."""
-        return self._config[CONF_STEP]
-
-    @property
-    def native_unit_of_measurement(self) -> str | None:
-        """Return the unit of measurement."""
-        return self._config.get(CONF_UNIT_OF_MEASUREMENT)
-
-    @property
-    def native_value(self) -> float | None:
-        """Return the current value."""
-        return self._current_number
-
-    @property
-    def mode(self) -> NumberMode:
-        """Return the mode of the entity."""
-        return self._config[CONF_MODE]
+            self._attr_native_value = last_number_data.native_value
 
     async def async_set_native_value(self, value: float) -> None:
         """Update the current value."""
@@ -287,10 +255,10 @@ class MqttNumber(MqttEntity, RestoreNumber):
 
         if value.is_integer():
             current_number = int(value)
-        payload = self._templates[CONF_COMMAND_TEMPLATE](current_number)
+        payload = self._command_template(current_number)
 
         if self._optimistic:
-            self._current_number = current_number
+            self._attr_native_value = current_number
             self.async_write_ha_state()
 
         await self.async_publish(
@@ -305,8 +273,3 @@ class MqttNumber(MqttEntity, RestoreNumber):
     def assumed_state(self) -> bool:
         """Return true if we do optimistic updates."""
         return self._optimistic
-
-    @property
-    def device_class(self) -> NumberDeviceClass | None:
-        """Return the device class of the sensor."""
-        return self._config.get(CONF_DEVICE_CLASS)
