@@ -1,4 +1,9 @@
 """Support for Legacy MQTT vacuum."""
+from __future__ import annotations
+
+from collections.abc import Callable
+from typing import Any
+
 import voluptuous as vol
 
 from homeassistant.components.vacuum import (
@@ -8,18 +13,26 @@ from homeassistant.components.vacuum import (
     VacuumEntity,
     VacuumEntityFeature,
 )
+from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import ATTR_SUPPORTED_FEATURES, CONF_NAME
-from homeassistant.core import callback
+from homeassistant.core import HomeAssistant, callback
 import homeassistant.helpers.config_validation as cv
+from homeassistant.helpers.entity_platform import AddEntitiesCallback
 from homeassistant.helpers.icon import icon_for_battery_level
 from homeassistant.helpers.json import json_dumps
+from homeassistant.helpers.typing import ConfigType, DiscoveryInfoType
 
 from .. import subscription
 from ..config import MQTT_BASE_SCHEMA
 from ..const import CONF_COMMAND_TOPIC, CONF_ENCODING, CONF_QOS, CONF_RETAIN
 from ..debug_info import log_messages
 from ..mixins import MQTT_ENTITY_COMMON_SCHEMA, MqttEntity, warn_for_legacy_schema
-from ..models import MqttValueTemplate
+from ..models import (
+    MqttValueTemplate,
+    PayloadSentinel,
+    ReceiveMessage,
+    ReceivePayloadType,
+)
 from ..util import get_mqtt_data, valid_publish_topic
 from .const import MQTT_VACUUM_ATTRIBUTES_BLOCKED
 from .schema import MQTT_VACUUM_SCHEMA, services_to_strings, strings_to_services
@@ -147,7 +160,7 @@ PLATFORM_SCHEMA_LEGACY_MODERN = (
     .extend(MQTT_VACUUM_SCHEMA.schema)
 )
 
-# Configuring MQTT Vacuums under the vacuum platform key is deprecated in HA Core 2022.6
+# Configuring MQTT Vacuums under the vacuum platform key was deprecated in HA Core 2022.6
 PLATFORM_SCHEMA_LEGACY = vol.All(
     cv.PLATFORM_SCHEMA.extend(PLATFORM_SCHEMA_LEGACY_MODERN.schema),
     warn_for_legacy_schema(VACUUM_DOMAIN),
@@ -158,9 +171,45 @@ DISCOVERY_SCHEMA_LEGACY = PLATFORM_SCHEMA_LEGACY_MODERN.extend(
 )
 
 
+_COMMANDS = {
+    VacuumEntityFeature.TURN_ON: {
+        "payload": CONF_PAYLOAD_TURN_ON,
+        "status": "Cleaning",
+    },
+    VacuumEntityFeature.TURN_OFF: {
+        "payload": CONF_PAYLOAD_TURN_OFF,
+        "status": "Turning Off",
+    },
+    VacuumEntityFeature.STOP: {
+        "payload": CONF_PAYLOAD_STOP,
+        "status": "Stopping the current task",
+    },
+    VacuumEntityFeature.CLEAN_SPOT: {
+        "payload": CONF_PAYLOAD_CLEAN_SPOT,
+        "status": "Cleaning spot",
+    },
+    VacuumEntityFeature.LOCATE: {
+        "payload": CONF_PAYLOAD_LOCATE,
+        "status": "Hi, I'm over here!",
+    },
+    VacuumEntityFeature.PAUSE: {
+        "payload": CONF_PAYLOAD_START_PAUSE,
+        "status": "Pausing/Resuming cleaning...",
+    },
+    VacuumEntityFeature.RETURN_HOME: {
+        "payload": CONF_PAYLOAD_RETURN_TO_BASE,
+        "status": "Returning home...",
+    },
+}
+
+
 async def async_setup_entity_legacy(
-    hass, config, async_add_entities, config_entry, discovery_data
-):
+    hass: HomeAssistant,
+    config: ConfigType,
+    async_add_entities: AddEntitiesCallback,
+    config_entry: ConfigEntry,
+    discovery_data: DiscoveryInfoType | None,
+) -> None:
     """Set up a MQTT Vacuum Legacy."""
     async_add_entities([MqttVacuum(hass, config, config_entry, discovery_data)])
 
@@ -171,30 +220,48 @@ class MqttVacuum(MqttEntity, VacuumEntity):
     _entity_id_format = ENTITY_ID_FORMAT
     _attributes_extra_blocked = MQTT_LEGACY_VACUUM_ATTRIBUTES_BLOCKED
 
-    def __init__(self, hass, config, config_entry, discovery_data):
+    _encoding: str | None
+    _qos: bool
+    _retain: bool
+    _payloads: dict[str, str]
+    _send_command_topic: str | None
+    _set_fan_speed_topic: str | None
+    _state_topics: dict[str, str | None]
+    _templates: dict[
+        str, Callable[[ReceivePayloadType, PayloadSentinel], ReceivePayloadType]
+    ]
+
+    def __init__(
+        self,
+        hass: HomeAssistant,
+        config: ConfigType,
+        config_entry: ConfigEntry,
+        discovery_data: DiscoveryInfoType | None,
+    ) -> None:
         """Initialize the vacuum."""
-        self._cleaning = False
+        self._attr_battery_level = 0
+        self._attr_is_on = False
+        self._attr_fan_speed = "unknown"
+
         self._charging = False
+        self._cleaning = False
         self._docked = False
-        self._error = None
-        self._status = "Unknown"
-        self._battery_level = 0
-        self._fan_speed = "unknown"
-        self._fan_speed_list = []
+        self._error: str | None = None
 
         MqttEntity.__init__(self, hass, config, config_entry, discovery_data)
 
     @staticmethod
-    def config_schema():
+    def config_schema() -> vol.Schema:
         """Return the config schema."""
         return DISCOVERY_SCHEMA_LEGACY
 
-    def _setup_from_config(self, config):
+    def _setup_from_config(self, config: ConfigType) -> None:
+        """(Re)Setup the entity."""
         supported_feature_strings = config[CONF_SUPPORTED_FEATURES]
-        self._supported_features = strings_to_services(
+        self._attr_supported_features = strings_to_services(
             supported_feature_strings, STRING_TO_SERVICE
         )
-        self._fan_speed_list = config[CONF_FAN_SPEED_LIST]
+        self._attr_fan_speed_list = config[CONF_FAN_SPEED_LIST]
         self._qos = config[CONF_QOS]
         self._retain = config[CONF_RETAIN]
         self._encoding = config[CONF_ENCODING] or None
@@ -204,7 +271,7 @@ class MqttVacuum(MqttEntity, VacuumEntity):
         self._send_command_topic = config.get(CONF_SEND_COMMAND_TOPIC)
 
         self._payloads = {
-            key: config.get(key)
+            key: config[key]
             for key in (
                 CONF_PAYLOAD_TURN_ON,
                 CONF_PAYLOAD_TURN_OFF,
@@ -227,7 +294,9 @@ class MqttVacuum(MqttEntity, VacuumEntity):
             )
         }
         self._templates = {
-            key: config.get(key)
+            key: MqttValueTemplate(
+                config[key], entity=self
+            ).async_render_with_possible_json_value
             for key in (
                 CONF_BATTERY_LEVEL_TEMPLATE,
                 CONF_CHARGING_TEMPLATE,
@@ -236,89 +305,87 @@ class MqttVacuum(MqttEntity, VacuumEntity):
                 CONF_ERROR_TEMPLATE,
                 CONF_FAN_SPEED_TEMPLATE,
             )
+            if key in config
         }
 
-    def _prepare_subscribe_topics(self):
+    def _prepare_subscribe_topics(self) -> None:
         """(Re)Subscribe to topics."""
-        for tpl in self._templates.values():
-            if tpl is not None:
-                tpl = MqttValueTemplate(tpl, entity=self)
 
         @callback
         @log_messages(self.hass, self.entity_id)
-        def message_received(msg):
+        def message_received(msg: ReceiveMessage) -> None:
             """Handle new MQTT message."""
             if (
                 msg.topic == self._state_topics[CONF_BATTERY_LEVEL_TOPIC]
-                and self._templates[CONF_BATTERY_LEVEL_TEMPLATE]
+                and CONF_BATTERY_LEVEL_TEMPLATE in self._config
             ):
-                battery_level = self._templates[
-                    CONF_BATTERY_LEVEL_TEMPLATE
-                ].async_render_with_possible_json_value(msg.payload, None)
-                if battery_level:
-                    self._battery_level = int(battery_level)
+                battery_level = self._templates[CONF_BATTERY_LEVEL_TEMPLATE](
+                    msg.payload, PayloadSentinel.DEFAULT
+                )
+                if battery_level and battery_level is not PayloadSentinel.DEFAULT:
+                    self._attr_battery_level = max(0, min(100, int(battery_level)))
 
             if (
                 msg.topic == self._state_topics[CONF_CHARGING_TOPIC]
-                and self._templates[CONF_CHARGING_TEMPLATE]
+                and CONF_CHARGING_TEMPLATE in self._templates
             ):
-                charging = self._templates[
-                    CONF_CHARGING_TEMPLATE
-                ].async_render_with_possible_json_value(msg.payload, None)
-                if charging:
+                charging = self._templates[CONF_CHARGING_TEMPLATE](
+                    msg.payload, PayloadSentinel.DEFAULT
+                )
+                if charging and charging is not PayloadSentinel.DEFAULT:
                     self._charging = cv.boolean(charging)
 
             if (
                 msg.topic == self._state_topics[CONF_CLEANING_TOPIC]
-                and self._templates[CONF_CLEANING_TEMPLATE]
+                and CONF_CLEANING_TEMPLATE in self._config
             ):
-                cleaning = self._templates[
-                    CONF_CLEANING_TEMPLATE
-                ].async_render_with_possible_json_value(msg.payload, None)
-                if cleaning:
-                    self._cleaning = cv.boolean(cleaning)
+                cleaning = self._templates[CONF_CLEANING_TEMPLATE](
+                    msg.payload, PayloadSentinel.DEFAULT
+                )
+                if cleaning and cleaning is not PayloadSentinel.DEFAULT:
+                    self._attr_is_on = cv.boolean(cleaning)
 
             if (
                 msg.topic == self._state_topics[CONF_DOCKED_TOPIC]
-                and self._templates[CONF_DOCKED_TEMPLATE]
+                and CONF_DOCKED_TEMPLATE in self._config
             ):
-                docked = self._templates[
-                    CONF_DOCKED_TEMPLATE
-                ].async_render_with_possible_json_value(msg.payload, None)
-                if docked:
+                docked = self._templates[CONF_DOCKED_TEMPLATE](
+                    msg.payload, PayloadSentinel.DEFAULT
+                )
+                if docked and docked is not PayloadSentinel.DEFAULT:
                     self._docked = cv.boolean(docked)
 
             if (
                 msg.topic == self._state_topics[CONF_ERROR_TOPIC]
-                and self._templates[CONF_ERROR_TEMPLATE]
+                and CONF_ERROR_TEMPLATE in self._config
             ):
-                error = self._templates[
-                    CONF_ERROR_TEMPLATE
-                ].async_render_with_possible_json_value(msg.payload, None)
-                if error is not None:
+                error = self._templates[CONF_ERROR_TEMPLATE](
+                    msg.payload, PayloadSentinel.DEFAULT
+                )
+                if error is not PayloadSentinel.DEFAULT:
                     self._error = cv.string(error)
 
             if self._docked:
                 if self._charging:
-                    self._status = "Docked & Charging"
+                    self._attr_status = "Docked & Charging"
                 else:
-                    self._status = "Docked"
-            elif self._cleaning:
-                self._status = "Cleaning"
+                    self._attr_status = "Docked"
+            elif self.is_on:
+                self._attr_status = "Cleaning"
             elif self._error:
-                self._status = f"Error: {self._error}"
+                self._attr_status = f"Error: {self._error}"
             else:
-                self._status = "Stopped"
+                self._attr_status = "Stopped"
 
             if (
                 msg.topic == self._state_topics[CONF_FAN_SPEED_TOPIC]
-                and self._templates[CONF_FAN_SPEED_TEMPLATE]
+                and CONF_FAN_SPEED_TEMPLATE in self._config
             ):
-                fan_speed = self._templates[
-                    CONF_FAN_SPEED_TEMPLATE
-                ].async_render_with_possible_json_value(msg.payload, None)
-                if fan_speed:
-                    self._fan_speed = fan_speed
+                fan_speed = self._templates[CONF_FAN_SPEED_TEMPLATE](
+                    msg.payload, PayloadSentinel.DEFAULT
+                )
+                if fan_speed and fan_speed is not PayloadSentinel.DEFAULT:
+                    self._attr_fan_speed = str(fan_speed)
 
             get_mqtt_data(self.hass).state_write_requests.write_state_request(self)
 
@@ -337,37 +404,12 @@ class MqttVacuum(MqttEntity, VacuumEntity):
             },
         )
 
-    async def _subscribe_topics(self):
+    async def _subscribe_topics(self) -> None:
         """(Re)Subscribe to topics."""
         await subscription.async_subscribe_topics(self.hass, self._sub_state)
 
     @property
-    def is_on(self):
-        """Return true if vacuum is on."""
-        return self._cleaning
-
-    @property
-    def status(self):
-        """Return a status string for the vacuum."""
-        return self._status
-
-    @property
-    def fan_speed(self):
-        """Return the status of the vacuum."""
-        return self._fan_speed
-
-    @property
-    def fan_speed_list(self):
-        """Return the status of the vacuum."""
-        return self._fan_speed_list
-
-    @property
-    def battery_level(self):
-        """Return the status of the vacuum."""
-        return max(0, min(100, self._battery_level))
-
-    @property
-    def battery_icon(self):
+    def battery_icon(self) -> str:
         """Return the battery icon for the vacuum cleaner.
 
         No need to check VacuumEntityFeature.BATTERY, this won't be called if battery_level is None.
@@ -376,121 +418,57 @@ class MqttVacuum(MqttEntity, VacuumEntity):
             battery_level=self.battery_level, charging=self._charging
         )
 
-    @property
-    def supported_features(self):
-        """Flag supported features."""
-        return self._supported_features
+    async def _async_publish_command(self, feature: VacuumEntityFeature) -> None:
+        """Check for a missing feature or command topic."""
 
-    async def async_turn_on(self, **kwargs):
-        """Turn the vacuum on."""
-        if self.supported_features & VacuumEntityFeature.TURN_ON == 0:
+        if self._command_topic is None or self.supported_features & feature == 0:
             return
 
         await self.async_publish(
             self._command_topic,
-            self._payloads[CONF_PAYLOAD_TURN_ON],
-            self._qos,
-            self._retain,
-            self._encoding,
+            self._payloads[_COMMANDS[feature]["payload"]],
+            qos=self._qos,
+            retain=self._retain,
+            encoding=self._encoding,
         )
-        self._status = "Cleaning"
+        self._attr_status = _COMMANDS[feature]["status"]
         self.async_write_ha_state()
 
-    async def async_turn_off(self, **kwargs):
+    async def async_turn_on(self, **kwargs: Any) -> None:
+        """Turn the vacuum on."""
+        await self._async_publish_command(VacuumEntityFeature.TURN_ON)
+
+    async def async_turn_off(self, **kwargs: Any) -> None:
         """Turn the vacuum off."""
-        if self.supported_features & VacuumEntityFeature.TURN_OFF == 0:
-            return None
+        await self._async_publish_command(VacuumEntityFeature.TURN_OFF)
 
-        await self.async_publish(
-            self._command_topic,
-            self._payloads[CONF_PAYLOAD_TURN_OFF],
-            self._qos,
-            self._retain,
-            self._encoding,
-        )
-        self._status = "Turning Off"
-        self.async_write_ha_state()
-
-    async def async_stop(self, **kwargs):
+    async def async_stop(self, **kwargs: Any) -> None:
         """Stop the vacuum."""
-        if self.supported_features & VacuumEntityFeature.STOP == 0:
-            return None
+        await self._async_publish_command(VacuumEntityFeature.STOP)
 
-        await self.async_publish(
-            self._command_topic,
-            self._payloads[CONF_PAYLOAD_STOP],
-            self._qos,
-            self._retain,
-            self._encoding,
-        )
-        self._status = "Stopping the current task"
-        self.async_write_ha_state()
-
-    async def async_clean_spot(self, **kwargs):
+    async def async_clean_spot(self, **kwargs: Any) -> None:
         """Perform a spot clean-up."""
-        if self.supported_features & VacuumEntityFeature.CLEAN_SPOT == 0:
-            return None
+        await self._async_publish_command(VacuumEntityFeature.CLEAN_SPOT)
 
-        await self.async_publish(
-            self._command_topic,
-            self._payloads[CONF_PAYLOAD_CLEAN_SPOT],
-            self._qos,
-            self._retain,
-            self._encoding,
-        )
-        self._status = "Cleaning spot"
-        self.async_write_ha_state()
-
-    async def async_locate(self, **kwargs):
+    async def async_locate(self, **kwargs: Any) -> None:
         """Locate the vacuum (usually by playing a song)."""
-        if self.supported_features & VacuumEntityFeature.LOCATE == 0:
-            return None
+        await self._async_publish_command(VacuumEntityFeature.LOCATE)
 
-        await self.async_publish(
-            self._command_topic,
-            self._payloads[CONF_PAYLOAD_LOCATE],
-            self._qos,
-            self._retain,
-            self._encoding,
-        )
-        self._status = "Hi, I'm over here!"
-        self.async_write_ha_state()
-
-    async def async_start_pause(self, **kwargs):
+    async def async_start_pause(self, **kwargs: Any) -> None:
         """Start, pause or resume the cleaning task."""
-        if self.supported_features & VacuumEntityFeature.PAUSE == 0:
-            return None
+        await self._async_publish_command(VacuumEntityFeature.PAUSE)
 
-        await self.async_publish(
-            self._command_topic,
-            self._payloads[CONF_PAYLOAD_START_PAUSE],
-            self._qos,
-            self._retain,
-            self._encoding,
-        )
-        self._status = "Pausing/Resuming cleaning..."
-        self.async_write_ha_state()
-
-    async def async_return_to_base(self, **kwargs):
+    async def async_return_to_base(self, **kwargs: Any) -> None:
         """Tell the vacuum to return to its dock."""
-        if self.supported_features & VacuumEntityFeature.RETURN_HOME == 0:
-            return None
+        await self._async_publish_command(VacuumEntityFeature.RETURN_HOME)
 
-        await self.async_publish(
-            self._command_topic,
-            self._payloads[CONF_PAYLOAD_RETURN_TO_BASE],
-            self._qos,
-            self._retain,
-            self._encoding,
-        )
-        self._status = "Returning home..."
-        self.async_write_ha_state()
-
-    async def async_set_fan_speed(self, fan_speed, **kwargs):
+    async def async_set_fan_speed(self, fan_speed: str, **kwargs: Any) -> None:
         """Set fan speed."""
         if (
-            self.supported_features & VacuumEntityFeature.FAN_SPEED == 0
-        ) or fan_speed not in self._fan_speed_list:
+            self._set_fan_speed_topic is None
+            or (self.supported_features & VacuumEntityFeature.FAN_SPEED == 0)
+            or fan_speed not in self.fan_speed_list
+        ):
             return None
 
         await self.async_publish(
@@ -500,25 +478,33 @@ class MqttVacuum(MqttEntity, VacuumEntity):
             self._retain,
             self._encoding,
         )
-        self._status = f"Setting fan to {fan_speed}..."
+        self._attr_status = f"Setting fan to {fan_speed}..."
         self.async_write_ha_state()
 
-    async def async_send_command(self, command, params=None, **kwargs):
+    async def async_send_command(
+        self,
+        command: str,
+        params: dict[str, Any] | list[Any] | None = None,
+        **kwargs: Any,
+    ) -> None:
         """Send a command to a vacuum cleaner."""
-        if self.supported_features & VacuumEntityFeature.SEND_COMMAND == 0:
+        if (
+            self._send_command_topic is None
+            or self.supported_features & VacuumEntityFeature.SEND_COMMAND == 0
+        ):
             return
         if params:
-            message = {"command": command}
+            message: dict[str, Any] = {"command": command}
             message.update(params)
-            message = json_dumps(message)
+            message_payload = json_dumps(message)
         else:
-            message = command
+            message_payload = command
         await self.async_publish(
             self._send_command_topic,
-            message,
+            message_payload,
             self._qos,
             self._retain,
             self._encoding,
         )
-        self._status = f"Sending command {message}..."
+        self._attr_status = f"Sending command {message_payload}..."
         self.async_write_ha_state()
