@@ -1,14 +1,21 @@
 """Config flow for Nibe Heat Pump integration."""
 from __future__ import annotations
 
-import errno
-from socket import gaierror
 from typing import Any
 
+from nibe.connection.modbus import Modbus
 from nibe.connection.nibegw import NibeGW
-from nibe.exceptions import CoilNotFoundException, CoilReadException, CoilWriteException
+from nibe.exceptions import (
+    AddressInUseException,
+    CoilNotFoundException,
+    CoilReadException,
+    CoilReadSendException,
+    CoilWriteException,
+    CoilWriteSendException,
+)
 from nibe.heatpump import HeatPump, Model
 import voluptuous as vol
+import yarl
 
 from homeassistant import config_entries
 from homeassistant.const import CONF_IP_ADDRESS, CONF_MODEL
@@ -18,8 +25,11 @@ from homeassistant.helpers import selector
 
 from .const import (
     CONF_CONNECTION_TYPE,
+    CONF_CONNECTION_TYPE_MODBUS,
     CONF_CONNECTION_TYPE_NIBEGW,
     CONF_LISTENING_PORT,
+    CONF_MODBUS_UNIT,
+    CONF_MODBUS_URL,
     CONF_REMOTE_READ_PORT,
     CONF_REMOTE_WRITE_PORT,
     CONF_WORD_SWAP,
@@ -36,7 +46,7 @@ PORT_SELECTOR = vol.All(
     vol.Coerce(int),
 )
 
-STEP_USER_DATA_SCHEMA = vol.Schema(
+STEP_NIBEGW_DATA_SCHEMA = vol.Schema(
     {
         vol.Required(CONF_MODEL): vol.In(list(Model.__members__)),
         vol.Required(CONF_IP_ADDRESS): selector.TextSelector(),
@@ -47,6 +57,22 @@ STEP_USER_DATA_SCHEMA = vol.Schema(
 )
 
 
+STEP_MODBUS_DATA_SCHEMA = vol.Schema(
+    {
+        vol.Required(CONF_MODEL): vol.In(list(Model.__members__)),
+        vol.Required(CONF_MODBUS_URL): selector.TextSelector(),
+        vol.Required(CONF_MODBUS_UNIT, default=0): vol.All(
+            selector.NumberSelector(
+                selector.NumberSelectorConfig(
+                    min=0, step=1, mode=selector.NumberSelectorMode.BOX
+                )
+            ),
+            vol.Coerce(int),
+        ),
+    }
+)
+
+
 class FieldError(Exception):
     """Field with invalid data."""
 
@@ -57,11 +83,13 @@ class FieldError(Exception):
         self.error = error
 
 
-async def validate_input(hass: HomeAssistant, data: dict[str, Any]) -> dict[str, Any]:
+async def validate_nibegw_input(
+    hass: HomeAssistant, data: dict[str, Any]
+) -> tuple[str, dict[str, Any]]:
     """Validate the user input allows us to connect."""
 
     heatpump = HeatPump(Model[data[CONF_MODEL]])
-    heatpump.initialize()
+    await heatpump.initialize()
 
     connection = NibeGW(
         heatpump,
@@ -73,24 +101,17 @@ async def validate_input(hass: HomeAssistant, data: dict[str, Any]) -> dict[str,
 
     try:
         await connection.start()
-    except OSError as exception:
-        if exception.errno == errno.EADDRINUSE:
-            raise FieldError(
-                "Address already in use", "listening_port", "address_in_use"
-            ) from exception
-        raise
+    except AddressInUseException as exception:
+        raise FieldError(
+            "Address already in use", "listening_port", "address_in_use"
+        ) from exception
 
     try:
-        coil = heatpump.get_coil_by_name("modbus40-word-swap-48852")
-        coil = await connection.read_coil(coil)
-        word_swap = coil.value == "ON"
-        coil = await connection.write_coil(coil)
-    except gaierror as exception:
-        raise FieldError(str(exception), "ip_address", "address") from exception
+        await connection.verify_connectivity()
+    except (CoilReadSendException, CoilWriteSendException) as exception:
+        raise FieldError(str(exception), CONF_IP_ADDRESS, "address") from exception
     except CoilNotFoundException as exception:
-        raise FieldError(
-            "Model selected doesn't seem to support expected coils", "base", "model"
-        ) from exception
+        raise FieldError("Coils not found", "base", "model") from exception
     except CoilReadException as exception:
         raise FieldError("Timeout on read from pump", "base", "read") from exception
     except CoilWriteException as exception:
@@ -98,9 +119,49 @@ async def validate_input(hass: HomeAssistant, data: dict[str, Any]) -> dict[str,
     finally:
         await connection.stop()
 
-    return {
-        "title": f"{data[CONF_MODEL]} at {data[CONF_IP_ADDRESS]}",
-        CONF_WORD_SWAP: word_swap,
+    return f"{data[CONF_MODEL]} at {data[CONF_IP_ADDRESS]}", {
+        **data,
+        CONF_WORD_SWAP: heatpump.word_swap,
+        CONF_CONNECTION_TYPE: CONF_CONNECTION_TYPE_NIBEGW,
+    }
+
+
+async def validate_modbus_input(
+    hass: HomeAssistant, data: dict[str, Any]
+) -> tuple[str, dict[str, Any]]:
+    """Validate the user input allows us to connect."""
+
+    heatpump = HeatPump(Model[data[CONF_MODEL]])
+    await heatpump.initialize()
+
+    try:
+        connection = Modbus(
+            heatpump,
+            data[CONF_MODBUS_URL],
+            data[CONF_MODBUS_UNIT],
+        )
+    except ValueError as exc:
+        raise FieldError("Not a valid modbus url", CONF_MODBUS_URL, "url") from exc
+
+    await connection.start()
+
+    try:
+        await connection.verify_connectivity()
+    except (CoilReadSendException, CoilWriteSendException) as exception:
+        raise FieldError(str(exception), CONF_MODBUS_URL, "address") from exception
+    except CoilNotFoundException as exception:
+        raise FieldError("Coils not found", "base", "model") from exception
+    except CoilReadException as exception:
+        raise FieldError("Timeout on read from pump", "base", "read") from exception
+    except CoilWriteException as exception:
+        raise FieldError("Timeout on writing to pump", "base", "write") from exception
+    finally:
+        await connection.stop()
+
+    host = yarl.URL(data[CONF_MODBUS_URL]).host
+    return f"{data[CONF_MODEL]} at {host}", {
+        **data,
+        CONF_CONNECTION_TYPE: CONF_CONNECTION_TYPE_MODBUS,
     }
 
 
@@ -113,15 +174,21 @@ class ConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
         self, user_input: dict[str, Any] | None = None
     ) -> FlowResult:
         """Handle the initial step."""
+        return self.async_show_menu(step_id="user", menu_options=["modbus", "nibegw"])
+
+    async def async_step_modbus(
+        self, user_input: dict[str, Any] | None = None
+    ) -> FlowResult:
+        """Handle the modbus step."""
         if user_input is None:
             return self.async_show_form(
-                step_id="user", data_schema=STEP_USER_DATA_SCHEMA
+                step_id="modbus", data_schema=STEP_MODBUS_DATA_SCHEMA
             )
 
         errors = {}
 
         try:
-            info = await validate_input(self.hass, user_input)
+            title, data = await validate_modbus_input(self.hass, user_input)
         except FieldError as exception:
             LOGGER.debug("Validation error %s", exception)
             errors[exception.field] = exception.error
@@ -129,13 +196,34 @@ class ConfigFlow(config_entries.ConfigFlow, domain=DOMAIN):
             LOGGER.exception("Unexpected exception")
             errors["base"] = "unknown"
         else:
-            data = {
-                **user_input,
-                CONF_WORD_SWAP: info[CONF_WORD_SWAP],
-                CONF_CONNECTION_TYPE: CONF_CONNECTION_TYPE_NIBEGW,
-            }
-            return self.async_create_entry(title=info["title"], data=data)
+            return self.async_create_entry(title=title, data=data)
 
         return self.async_show_form(
-            step_id="user", data_schema=STEP_USER_DATA_SCHEMA, errors=errors
+            step_id="modbus", data_schema=STEP_MODBUS_DATA_SCHEMA, errors=errors
+        )
+
+    async def async_step_nibegw(
+        self, user_input: dict[str, Any] | None = None
+    ) -> FlowResult:
+        """Handle the nibegw step."""
+        if user_input is None:
+            return self.async_show_form(
+                step_id="nibegw", data_schema=STEP_NIBEGW_DATA_SCHEMA
+            )
+
+        errors = {}
+
+        try:
+            title, data = await validate_nibegw_input(self.hass, user_input)
+        except FieldError as exception:
+            LOGGER.exception("Validation error")
+            errors[exception.field] = exception.error
+        except Exception:  # pylint: disable=broad-except
+            LOGGER.exception("Unexpected exception")
+            errors["base"] = "unknown"
+        else:
+            return self.async_create_entry(title=title, data=data)
+
+        return self.async_show_form(
+            step_id="nibegw", data_schema=STEP_NIBEGW_DATA_SCHEMA, errors=errors
         )
