@@ -11,7 +11,7 @@ from httpx import RequestError
 import onvif
 from onvif import ONVIFCamera
 from onvif.exceptions import ONVIFError
-from zeep.exceptions import Fault
+from zeep.exceptions import Fault, XMLParseError
 
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import (
@@ -74,12 +74,12 @@ class ONVIFDevice:
         return self.config_entry.data[CONF_PORT]
 
     @property
-    def username(self) -> int:
+    def username(self) -> str:
         """Return the username of this device."""
         return self.config_entry.data[CONF_USERNAME]
 
     @property
-    def password(self) -> int:
+    def password(self) -> str:
         """Return the password of this device."""
         return self.config_entry.data[CONF_PASSWORD]
 
@@ -284,7 +284,7 @@ class ONVIFDevice:
             snapshot = media_capabilities and media_capabilities.SnapshotUri
 
         pullpoint = False
-        with suppress(ONVIFError, Fault, RequestError):
+        with suppress(ONVIFError, Fault, RequestError, XMLParseError):
             pullpoint = await self.events.async_start()
 
         ptz = False
