@@ -15,7 +15,7 @@ import rjpl
 import voluptuous as vol
 
 from homeassistant.components.sensor import PLATFORM_SCHEMA, SensorEntity
-from homeassistant.const import ATTR_ATTRIBUTION, CONF_NAME, TIME_MINUTES
+from homeassistant.const import CONF_NAME, TIME_MINUTES
 from homeassistant.core import HomeAssistant
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
@@ -37,8 +37,6 @@ ATTR_REAL_TIME_AT = "real_time_at"
 ATTR_TRACK = "track"
 ATTR_NEXT_UP = "next_departures"
 
-ATTRIBUTION = "Data provided by rejseplanen.dk"
-
 CONF_STOP_ID = "stop_id"
 CONF_ROUTE = "route"
 CONF_DIRECTION = "direction"
@@ -100,6 +98,8 @@ def setup_platform(
 class RejseplanenTransportSensor(SensorEntity):
     """Implementation of Rejseplanen transport sensor."""
 
+    _attr_attribution = "Data provided by rejseplanen.dk"
+
     def __init__(self, data, stop_id, route, direction, name):
         """Initialize the sensor."""
         self.data = data
@@ -123,14 +123,13 @@ class RejseplanenTransportSensor(SensorEntity):
     def extra_state_attributes(self):
         """Return the state attributes."""
         if not self._times:
-            return {ATTR_STOP_ID: self._stop_id, ATTR_ATTRIBUTION: ATTRIBUTION}
+            return {ATTR_STOP_ID: self._stop_id}
 
         next_up = []
         if len(self._times) > 1:
             next_up = self._times[1:]
 
         attributes = {
-            ATTR_ATTRIBUTION: ATTRIBUTION,
             ATTR_NEXT_UP: next_up,
             ATTR_STOP_ID: self._stop_id,
         }
