@@ -1,7 +1,11 @@
-"""Number platform for Sensibo integration."""
+"""Select platform for Sensibo integration."""
 from __future__ import annotations
 
+from collections.abc import Callable
 from dataclasses import dataclass
+from typing import TYPE_CHECKING, Any
+
+from pysensibo.model import SensiboDevice
 
 from homeassistant.components.select import SelectEntity, SelectEntityDescription
 from homeassistant.config_entries import ConfigEntry
@@ -11,7 +15,7 @@ from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
 from .const import DOMAIN
 from .coordinator import SensiboDataUpdateCoordinator
-from .entity import SensiboDeviceBaseEntity
+from .entity import SensiboDeviceBaseEntity, async_handle_api_call
 
 PARALLEL_UPDATES = 0
 
@@ -20,31 +24,34 @@ PARALLEL_UPDATES = 0
 class SensiboSelectDescriptionMixin:
     """Mixin values for Sensibo entities."""
 
-    remote_key: str
-    remote_options: str
+    data_key: str
+    value_fn: Callable[[SensiboDevice], str | None]
+    options_fn: Callable[[SensiboDevice], list[str] | None]
 
 
 @dataclass
 class SensiboSelectEntityDescription(
     SelectEntityDescription, SensiboSelectDescriptionMixin
 ):
-    """Class describing Sensibo Number entities."""
+    """Class describing Sensibo Select entities."""
 
 
 DEVICE_SELECT_TYPES = (
     SensiboSelectEntityDescription(
         key="horizontalSwing",
-        remote_key="horizontal_swing_mode",
-        remote_options="horizontal_swing_modes",
+        data_key="horizontal_swing_mode",
         name="Horizontal swing",
         icon="mdi:air-conditioner",
+        value_fn=lambda data: data.horizontal_swing_mode,
+        options_fn=lambda data: data.horizontal_swing_modes,
     ),
     SensiboSelectEntityDescription(
         key="light",
-        remote_key="light_mode",
-        remote_options="light_modes",
+        data_key="light_mode",
         name="Light",
         icon="mdi:flashlight",
+        value_fn=lambda data: data.light_mode,
+        options_fn=lambda data: data.light_modes,
     ),
 )
 
@@ -83,15 +90,15 @@ class SensiboSelect(SensiboDeviceBaseEntity, SelectEntity):
     @property
     def current_option(self) -> str | None:
         """Return the current selected option."""
-        option: str | None = getattr(
-            self.device_data, self.entity_description.remote_key
-        )
-        return option
+        return self.entity_description.value_fn(self.device_data)
 
     @property
     def options(self) -> list[str]:
         """Return possible options."""
-        return getattr(self.device_data, self.entity_description.remote_options) or []
+        options = self.entity_description.options_fn(self.device_data)
+        if TYPE_CHECKING:
+            assert options is not None
+        return options
 
     async def async_select_option(self, option: str) -> None:
         """Set state to the selected option."""
@@ -100,20 +107,25 @@ class SensiboSelect(SensiboDeviceBaseEntity, SelectEntity):
                 f"Current mode {self.device_data.hvac_mode} doesn't support setting {self.entity_description.name}"
             )
 
-        params = {
+        await self.async_send_api_call(
+            key=self.entity_description.data_key,
+            value=option,
+        )
+
+    @async_handle_api_call
+    async def async_send_api_call(self, key: str, value: Any) -> bool:
+        """Make service call to api."""
+        data = {
             "name": self.entity_description.key,
-            "value": option,
+            "value": value,
             "ac_states": self.device_data.ac_states,
             "assumed_state": False,
         }
-        result = await self.async_send_command("set_ac_state", params)
-
-        if result["result"]["status"] == "Success":
-            setattr(self.device_data, self.entity_description.remote_key, option)
-            self.async_write_ha_state()
-            return
-
-        failure = result["result"]["failureReason"]
-        raise HomeAssistantError(
-            f"Could not set state for device {self.name} due to reason {failure}"
+        result = await self._client.async_set_ac_state_property(
+            self._device_id,
+            data["name"],
+            data["value"],
+            data["ac_states"],
+            data["assumed_state"],
         )
+        return bool(result.get("result", {}).get("status") == "Success")
