@@ -23,7 +23,6 @@ from homeassistant.const import (
     PERCENTAGE,
     SIGNAL_STRENGTH_DECIBELS_MILLIWATT,
     TEMP_CELSIUS,
-    TEMP_FAHRENHEIT,
 )
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers.entity import EntityCategory
@@ -155,6 +154,32 @@ DEVICE_SENSOR_TYPES: tuple[SensiboDeviceSensorEntityDescription, ...] = (
         extra_fn=None,
         entity_registry_enabled_default=False,
     ),
+    SensiboDeviceSensorEntityDescription(
+        key="climate_react_low",
+        device_class=SensorDeviceClass.TEMPERATURE,
+        state_class=SensorStateClass.MEASUREMENT,
+        name="Climate React low temperature threshold",
+        value_fn=lambda data: data.smart_low_temp_threshold,
+        extra_fn=lambda data: data.smart_low_state,
+        entity_registry_enabled_default=False,
+    ),
+    SensiboDeviceSensorEntityDescription(
+        key="climate_react_high",
+        device_class=SensorDeviceClass.TEMPERATURE,
+        state_class=SensorStateClass.MEASUREMENT,
+        name="Climate React high temperature threshold",
+        value_fn=lambda data: data.smart_high_temp_threshold,
+        extra_fn=lambda data: data.smart_high_state,
+        entity_registry_enabled_default=False,
+    ),
+    SensiboDeviceSensorEntityDescription(
+        key="climate_react_type",
+        device_class="sensibo__smart_type",
+        name="Climate React type",
+        value_fn=lambda data: data.smart_type,
+        extra_fn=None,
+        entity_registry_enabled_default=False,
+    ),
     FILTER_LAST_RESET_DESCRIPTION,
 )
 
@@ -179,7 +204,56 @@ AIRQ_SENSOR_TYPES: tuple[SensiboDeviceSensorEntityDescription, ...] = (
     ),
 )
 
-DESCRIPTION_BY_MODELS = {"pure": PURE_SENSOR_TYPES, "airq": AIRQ_SENSOR_TYPES}
+ELEMENT_SENSOR_TYPES: tuple[SensiboDeviceSensorEntityDescription, ...] = (
+    SensiboDeviceSensorEntityDescription(
+        key="pm25",
+        device_class=SensorDeviceClass.PM25,
+        native_unit_of_measurement=CONCENTRATION_MICROGRAMS_PER_CUBIC_METER,
+        state_class=SensorStateClass.MEASUREMENT,
+        name="PM 2.5",
+        value_fn=lambda data: data.pm25,
+        extra_fn=None,
+    ),
+    SensiboDeviceSensorEntityDescription(
+        key="tvoc",
+        native_unit_of_measurement=CONCENTRATION_PARTS_PER_BILLION,
+        state_class=SensorStateClass.MEASUREMENT,
+        name="TVOC",
+        value_fn=lambda data: data.tvoc,
+        extra_fn=None,
+    ),
+    SensiboDeviceSensorEntityDescription(
+        key="co2",
+        device_class=SensorDeviceClass.CO2,
+        native_unit_of_measurement=CONCENTRATION_PARTS_PER_MILLION,
+        state_class=SensorStateClass.MEASUREMENT,
+        name="CO2",
+        value_fn=lambda data: data.co2,
+        extra_fn=None,
+    ),
+    SensiboDeviceSensorEntityDescription(
+        key="ethanol",
+        native_unit_of_measurement=CONCENTRATION_PARTS_PER_MILLION,
+        state_class=SensorStateClass.MEASUREMENT,
+        name="Ethanol",
+        value_fn=lambda data: data.etoh,
+        extra_fn=None,
+    ),
+    SensiboDeviceSensorEntityDescription(
+        key="iaq",
+        device_class=SensorDeviceClass.AQI,
+        state_class=SensorStateClass.MEASUREMENT,
+        name="Air quality",
+        value_fn=lambda data: data.iaq,
+        extra_fn=None,
+    ),
+)
+
+DESCRIPTION_BY_MODELS = {
+    "pure": PURE_SENSOR_TYPES,
+    "airq": AIRQ_SENSOR_TYPES,
+    "elements": ELEMENT_SENSOR_TYPES,
+}
 
 
 async def async_setup_entry(
@@ -237,9 +311,7 @@ class SensiboMotionSensor(SensiboMotionBaseEntity, SensorEntity):
     def native_unit_of_measurement(self) -> str | None:
         """Add native unit of measurement."""
         if self.entity_description.device_class == SensorDeviceClass.TEMPERATURE:
-            return (
-                TEMP_CELSIUS if self.device_data.temp_unit == "C" else TEMP_FAHRENHEIT
-            )
+            return TEMP_CELSIUS
         return self.entity_description.native_unit_of_measurement
 
     @property
@@ -273,15 +345,16 @@ class SensiboDeviceSensor(SensiboDeviceBaseEntity, SensorEntity):
     def native_unit_of_measurement(self) -> str | None:
         """Add native unit of measurement."""
         if self.entity_description.device_class == SensorDeviceClass.TEMPERATURE:
-            return (
-                TEMP_CELSIUS if self.device_data.temp_unit == "C" else TEMP_FAHRENHEIT
-            )
+            return TEMP_CELSIUS
         return self.entity_description.native_unit_of_measurement
 
     @property
     def native_value(self) -> StateType | datetime:
         """Return value of sensor."""
-        return self.entity_description.value_fn(self.device_data)
+        state = self.entity_description.value_fn(self.device_data)
+        if isinstance(state, str):
+            return state.lower()
+        return state
 
     @property
     def extra_state_attributes(self) -> Mapping[str, Any] | None:
