@@ -21,12 +21,7 @@ from homeassistant.helpers.typing import StateType
 from homeassistant.helpers.update_coordinator import CoordinatorEntity
 
 from .const import CONF_SLEEP_PERIOD, LOGGER
-from .coordinator import (
-    ShellyBlockCoordinator,
-    ShellyRpcCoordinator,
-    ShellyRpcPollingCoordinator,
-    get_entry_data,
-)
+from .coordinator import ShellyBlockCoordinator, ShellyRpcCoordinator, get_entry_data
 from .utils import (
     async_remove_shelly_entity,
     get_block_entity_name,
@@ -269,21 +264,10 @@ def async_setup_entry_rest(
     """Set up entities for REST sensors."""
     coordinator = get_entry_data(hass)[config_entry.entry_id].rest
     assert coordinator
-    entities = []
-    for sensor_id in sensors:
-        description = sensors.get(sensor_id)
-
-        if not coordinator.device.settings.get("sleep_mode"):
-            entities.append((sensor_id, description))
-
-    if not entities:
-        return
 
     async_add_entities(
-        [
-            sensor_class(coordinator, sensor_id, description)
-            for sensor_id, description in entities
-        ]
+        sensor_class(coordinator, sensor_id, sensors[sensor_id])
+        for sensor_id in sensors
     )
 
 
@@ -350,10 +334,6 @@ class ShellyBlockEntity(CoordinatorEntity[ShellyBlockCoordinator]):
         """When entity is added to HASS."""
         self.async_on_remove(self.coordinator.async_add_listener(self._update_callback))
 
-    async def async_update(self) -> None:
-        """Update entity with latest info."""
-        await self.coordinator.async_request_refresh()
-
     @callback
     def _update_callback(self) -> None:
         """Handle device update."""
@@ -373,16 +353,12 @@ class ShellyBlockEntity(CoordinatorEntity[ShellyBlockCoordinator]):
             self.coordinator.entry.async_start_reauth(self.hass)
 
 
-class ShellyRpcEntity(entity.Entity):
+class ShellyRpcEntity(CoordinatorEntity[ShellyRpcCoordinator]):
     """Helper class to represent a rpc entity."""
 
-    def __init__(
-        self,
-        coordinator: ShellyRpcCoordinator | ShellyRpcPollingCoordinator,
-        key: str,
-    ) -> None:
+    def __init__(self, coordinator: ShellyRpcCoordinator, key: str) -> None:
         """Initialize Shelly entity."""
-        self.coordinator = coordinator
+        super().__init__(coordinator)
         self.key = key
         self._attr_should_poll = False
         self._attr_device_info = {
@@ -405,10 +381,6 @@ class ShellyRpcEntity(entity.Entity):
         """When entity is added to HASS."""
         self.async_on_remove(self.coordinator.async_add_listener(self._update_callback))
 
-    async def async_update(self) -> None:
-        """Update entity with latest info."""
-        await self.coordinator.async_request_refresh()
-
     @callback
     def _update_callback(self) -> None:
         """Handle device update."""
@@ -525,16 +497,6 @@ class ShellyRestAttributeEntity(CoordinatorEntity[ShellyBlockCoordinator]):
             )
         return self._last_value
 
-    @property
-    def extra_state_attributes(self) -> dict[str, Any] | None:
-        """Return the state attributes."""
-        if self.entity_description.extra_state_attributes is None:
-            return None
-
-        return self.entity_description.extra_state_attributes(
-            self.block_coordinator.device.status
-        )
-
 
 class ShellyRpcAttributeEntity(ShellyRpcEntity, entity.Entity):
     """Helper class to represent a rpc attribute."""
@@ -586,19 +548,6 @@ class ShellyRpcAttributeEntity(ShellyRpcEntity, entity.Entity):
             self.coordinator.device.status[self.key][self.entity_description.sub_key]
         )
 
-    @property
-    def extra_state_attributes(self) -> dict[str, Any] | None:
-        """Return the state attributes."""
-        if self.entity_description.extra_state_attributes is None:
-            return None
-
-        assert self.coordinator.device.shelly
-
-        return self.entity_description.extra_state_attributes(
-            self.coordinator.device.status[self.key][self.entity_description.sub_key],
-            self.coordinator.device.shelly,
-        )
-
 
 class ShellySleepingBlockAttributeEntity(ShellyBlockAttributeEntity, RestoreEntity):
     """Represent a shelly sleeping block attribute entity."""
