@@ -13,6 +13,7 @@ from homeassistant.const import (
     CONF_AFTER,
     CONF_BEFORE,
     CONF_NAME,
+    CONF_UNIQUE_ID,
     SUN_EVENT_SUNRISE,
     SUN_EVENT_SUNSET,
 )
@@ -43,6 +44,7 @@ PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
         vol.Required(CONF_NAME): cv.string,
         vol.Optional(CONF_AFTER_OFFSET, default=timedelta(0)): cv.time_period,
         vol.Optional(CONF_BEFORE_OFFSET, default=timedelta(0)): cv.time_period,
+        vol.Optional(CONF_UNIQUE_ID): cv.string,
     }
 )
 
@@ -85,7 +87,8 @@ async def async_setup_platform(
     before = config[CONF_BEFORE]
     before_offset = config[CONF_BEFORE_OFFSET]
     name = config[CONF_NAME]
-    sensor = TodSensor(name, after, after_offset, before, before_offset, None)
+    unique_id = config.get(CONF_UNIQUE_ID)
+    sensor = TodSensor(name, after, after_offset, before, before_offset, unique_id)
 
     async_add_entities([sensor])
 
