@@ -64,6 +64,24 @@ def async_register_scan_request_callback(
 @hass_callback
 def async_is_plugged_in(hass: HomeAssistant, matcher: USBCallbackMatcher) -> bool:
     """Return True is a USB device is present."""
+
+    vid = matcher.get("vid", "")
+    pid = matcher.get("pid", "")
+    serial_number = matcher.get("serial_number", "")
+    manufacturer = matcher.get("manufacturer", "")
+    description = matcher.get("description", "")
+
+    if (
+        vid != vid.upper()
+        or pid != pid.upper()
+        or serial_number != serial_number.lower()
+        or manufacturer != manufacturer.lower()
+        or description != description.lower()
+    ):
+        raise ValueError(
+            f"vid and pid must be uppercase, the rest lowercase in matcher {matcher!r}"
+        )
+
     usb_discovery: USBDiscovery = hass.data[DOMAIN]
     return any(
         _is_matching(USBDevice(*device_tuple), matcher)
