@@ -73,8 +73,8 @@ def ha_dev_type(device):
 
 
 FILTER_LIFE_SUPPORTED = ["LV-PUR131S", "Core200S", "Core300S", "Core400S", "Core600S"]
-AIR_QUALITY_SUPPORTED = ["LV-PUR131S", "Core400S", "Core600S"]
-PM25_SUPPORTED = ["Core400S", "Core600S"]
+AIR_QUALITY_SUPPORTED = ["LV-PUR131S", "Core300S", "Core400S", "Core600S"]
+PM25_SUPPORTED = ["Core300S", "Core400S", "Core600S"]
 
 SENSORS: tuple[VeSyncSensorEntityDescription, ...] = (
     VeSyncSensorEntityDescription(
