@@ -15,6 +15,7 @@ from homeassistant.const import (
     CONF_REGION,
     CONF_RESOURCES,
     CONF_SCAN_INTERVAL,
+    CONF_UNIT_SYSTEM,
     CONF_USERNAME,
 )
 from homeassistant.core import HomeAssistant
@@ -22,6 +23,7 @@ from homeassistant.exceptions import ConfigEntryAuthFailed
 from homeassistant.helpers.aiohttp_client import async_get_clientsession
 import homeassistant.helpers.config_validation as cv
 from homeassistant.helpers.dispatcher import async_dispatcher_send
+from homeassistant.helpers.entity import DeviceInfo
 from homeassistant.helpers.issue_registry import IssueSeverity, async_create_issue
 from homeassistant.helpers.typing import ConfigType
 from homeassistant.helpers.update_coordinator import (
@@ -38,6 +40,9 @@ from .const import (
     DOMAIN,
     PLATFORMS,
     RESOURCES,
+    UNIT_SYSTEM_IMPERIAL,
+    UNIT_SYSTEM_METRIC,
+    UNIT_SYSTEM_SCANDINAVIAN_MILES,
     VOLVO_DISCOVERY_NEW,
 )
 from .errors import InvalidAuth
@@ -109,6 +114,19 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
 
 async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Set up the Volvo On Call component from a ConfigEntry."""
+
+    # added CONF_UNIT_SYSTEM / deprecated CONF_SCANDINAVIAN_MILES in 2022.10 to support imperial units
+    if CONF_UNIT_SYSTEM not in entry.data:
+        new_conf = {**entry.data}
+
+        scandinavian_miles: bool = entry.data[CONF_SCANDINAVIAN_MILES]
+
+        new_conf[CONF_UNIT_SYSTEM] = (
+            UNIT_SYSTEM_SCANDINAVIAN_MILES if scandinavian_miles else UNIT_SYSTEM_METRIC
+        )
+
+        hass.config_entries.async_update_entry(entry, data=new_conf)
+
     session = async_get_clientsession(hass)
 
     connection = Connection(
@@ -127,10 +145,7 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
         hass, volvo_data
     )
 
-    try:
-        await coordinator.async_config_entry_first_refresh()
-    except ConfigEntryAuthFailed:
-        return False
+    await coordinator.async_config_entry_first_refresh()
 
     await hass.config_entries.async_forward_entry_setups(entry, PLATFORMS)
 
@@ -186,7 +201,13 @@ class VolvoData:
 
         dashboard = vehicle.dashboard(
             mutable=self.config_entry.data[CONF_MUTABLE],
-            scandinavian_miles=self.config_entry.data[CONF_SCANDINAVIAN_MILES],
+            scandinavian_miles=(
+                self.config_entry.data[CONF_UNIT_SYSTEM]
+                == UNIT_SYSTEM_SCANDINAVIAN_MILES
+            ),
+            usa_units=(
+                self.config_entry.data[CONF_UNIT_SYSTEM] == UNIT_SYSTEM_IMPERIAL
+            ),
         )
 
         for instrument in (
@@ -199,15 +220,17 @@ class VolvoData:
 
     async def update(self):
         """Update status from the online service."""
-        if not await self.connection.update(journal=True):
-            return False
+        try:
+            await self.connection.update(journal=True)
+        except ClientResponseError as ex:
+            if ex.status == 401:
+                raise ConfigEntryAuthFailed(ex) from ex
+            raise UpdateFailed(ex) from ex
 
         for vehicle in self.connection.vehicles:
             if vehicle.vin not in self.vehicles:
                 self.discover_vehicle(vehicle)
 
-        return True
-
     async def auth_is_valid(self):
         """Check if provided username/password/region authenticate."""
         try:
@@ -235,8 +258,7 @@ class VolvoUpdateCoordinator(DataUpdateCoordinator):
         """Fetch data from API endpoint."""
 
         async with async_timeout.timeout(10):
-            if not await self.volvo_data.update():
-                raise UpdateFailed("Error communicating with API")
+            await self.volvo_data.update()
 
 
 class VolvoEntity(CoordinatorEntity):
@@ -293,6 +315,16 @@ class VolvoEntity(CoordinatorEntity):
         """Return true if unable to access real state of entity."""
         return True
 
+    @property
+    def device_info(self) -> DeviceInfo:
+        """Return a inique set of attributes for each vehicle."""
+        return DeviceInfo(
+            identifiers={(DOMAIN, self.vehicle.vin)},
+            name=self._vehicle_name,
+            model=self.vehicle.vehicle_type,
+            manufacturer="Volvo",
+        )
+
     @property
     def extra_state_attributes(self):
         """Return device specific state attributes."""
