@@ -4,7 +4,9 @@ from __future__ import annotations
 import abc
 import asyncio
 from collections.abc import Iterable, Mapping
+import copy
 from dataclasses import dataclass
+import logging
 from types import MappingProxyType
 from typing import Any, TypedDict
 
@@ -16,6 +18,8 @@ from .exceptions import HomeAssistantError
 from .helpers.frame import report
 from .util import uuid as uuid_util
 
+_LOGGER = logging.getLogger(__name__)
+
 
 class FlowResultType(StrEnum):
     """Result type for a data entry flow."""
@@ -175,7 +179,7 @@ class FlowManager(abc.ABC):
         )
 
     @callback
-    def async_get(self, flow_id: str) -> FlowResult | None:
+    def async_get(self, flow_id: str) -> FlowResult:
         """Return a flow in progress as a partial FlowResult."""
         if (flow := self._progress.get(flow_id)) is None:
             raise UnknownFlow
@@ -337,6 +341,11 @@ class FlowManager(abc.ABC):
         if not self._handler_progress_index[handler]:
             del self._handler_progress_index[handler]
 
+        try:
+            flow.async_remove()
+        except Exception as err:  # pylint: disable=broad-except
+            _LOGGER.exception("Error removing %s config flow: %s", flow.handler, err)
+
     async def _async_handle_step(
         self,
         flow: Any,
@@ -435,6 +444,34 @@ class FlowHandler:
         """If we should show advanced options."""
         return self.context.get("show_advanced_options", False)
 
+    def add_suggested_values_to_schema(
+        self, data_schema: vol.Schema, suggested_values: Mapping[str, Any]
+    ) -> vol.Schema:
+        """Make a copy of the schema, populated with suggested values.
+
+        For each schema marker matching items in `suggested_values`,
+        the `suggested_value` will be set. The existing `suggested_value` will
+        be left untouched if there is no matching item.
+        """
+        schema = {}
+        for key, val in data_schema.schema.items():
+            if isinstance(key, vol.Marker):
+                # Exclude advanced field
+                if (
+                    key.description
+                    and key.description.get("advanced")
+                    and not self.show_advanced_options
+                ):
+                    continue
+
+            new_key = key
+            if key in suggested_values and isinstance(key, vol.Marker):
+                # Copy the marker to not modify the flow schema
+                new_key = copy.copy(key)
+                new_key.description = {"suggested_value": suggested_values[key]}
+            schema[new_key] = val
+        return vol.Schema(schema)
+
     @callback
     def async_show_form(
         self,
@@ -476,6 +513,7 @@ class FlowHandler:
             data=data,
             description=description,
             description_placeholders=description_placeholders,
+            context=self.context,
         )
 
     @callback
@@ -568,6 +606,10 @@ class FlowHandler:
             description_placeholders=description_placeholders,
         )
 
+    @callback
+    def async_remove(self) -> None:
+        """Notification that the config flow has been removed."""
+
 
 @callback
 def _create_abort_data(
